"""
Python module generated from Java source file org.yaml.snakeyaml.events.DocumentStartEvent

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.DumperOptions import Version
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.events import *
from typing import Any, Callable, Iterable, Tuple


class DocumentStartEvent(Event):
    """
    Marks the beginning of a document.
    
    This event followed by the document's content and a DocumentEndEvent.
    """

    def __init__(self, startMark: "Mark", endMark: "Mark", explicit: bool, version: "Version", tags: dict[str, str]):
        """
        Create

        Arguments
        - startMark: - start
        - endMark: - end
        - explicit: - True when it is present in the document
        - version: - YAML version
        - tags: - tag directives
        """
        ...


    def getExplicit(self) -> bool:
        """
        getter

        Returns
        - True when document end is present
        """
        ...


    def getVersion(self) -> "Version":
        """
        YAML version the document conforms to.

        Returns
        - `null`if the document has no explicit `%YAML` directive.
                Otherwise an array with two components, the major and minor part of the version (in
                this order).
        """
        ...


    def getTags(self) -> dict[str, str]:
        """
        Tag shorthands as defined by the `%TAG` directive.

        Returns
        - Mapping of 'handles' to 'prefixes' (the handles include the '!' characters).
        """
        ...


    def getEventId(self) -> "Event.ID":
        ...



from .Consumer import Consumer
from .BooleanSupplier import BooleanSupplier
from .LongBinaryOperator import LongBinaryOperator
from .LongUnaryOperator import LongUnaryOperator
from .DoubleBinaryOperator import DoubleBinaryOperator
from .DoubleUnaryOperator import DoubleUnaryOperator
from .LongConsumer import LongConsumer
from .IntConsumer import IntConsumer
from .DoubleConsumer import DoubleConsumer
from .BiFunction import BiFunction
from .ObjIntConsumer import ObjIntConsumer
from .BinaryOperator import BinaryOperator
from .Function import Function
from .Supplier import Supplier
from .BiConsumer import BiConsumer
from .Predicate import Predicate
from .UnaryOperator import UnaryOperator
from .ToIntFunction import ToIntFunction
from .IntFunction import IntFunction
from .BiPredicate import BiPredicate


"""
Python module generated from Java source file java.util.GregorianCalendar

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import IOException
from java.io import ObjectInputStream
from java.time import Instant
from java.time import ZonedDateTime
from java.time.temporal import ChronoField
from java.util import *
from sun.util.calendar import BaseCalendar
from sun.util.calendar import CalendarDate
from sun.util.calendar import CalendarSystem
from sun.util.calendar import CalendarUtils
from sun.util.calendar import Era
from sun.util.calendar import Gregorian
from sun.util.calendar import JulianCalendar
from sun.util.calendar import ZoneInfo
from typing import Any, Callable, Iterable, Tuple


class GregorianCalendar(Calendar):
    """
    `GregorianCalendar` is a concrete subclass of
    `Calendar` and provides the standard calendar system
    used by most of the world.
    
     `GregorianCalendar` is a hybrid calendar that
    supports both the Julian and Gregorian calendar systems with the
    support of a single discontinuity, which corresponds by default to
    the Gregorian date when the Gregorian calendar was instituted
    (October 15, 1582 in some countries, later in others).  The cutover
    date may be changed by the caller by calling .setGregorianChange(Date) setGregorianChange().
    
    
    Historically, in those countries which adopted the Gregorian calendar first,
    October 4, 1582 (Julian) was thus followed by October 15, 1582 (Gregorian). This calendar models
    this correctly.  Before the Gregorian cutover, `GregorianCalendar`
    implements the Julian calendar.  The only difference between the Gregorian
    and the Julian calendar is the leap year rule. The Julian calendar specifies
    leap years every four years, whereas the Gregorian calendar omits century
    years which are not divisible by 400.
    
    
    `GregorianCalendar` implements *proleptic* Gregorian and
    Julian calendars. That is, dates are computed by extrapolating the current
    rules indefinitely far backward and forward in time. As a result,
    `GregorianCalendar` may be used for all years to generate
    meaningful and consistent results. However, dates obtained using
    `GregorianCalendar` are historically accurate only from March 1, 4
    AD onward, when modern Julian calendar rules were adopted.  Before this date,
    leap year rules were applied irregularly, and before 45 BC the Julian
    calendar did not even exist.
    
    
    Prior to the institution of the Gregorian calendar, New Year's Day was
    March 25. To avoid confusion, this calendar always uses January 1. A manual
    adjustment may be made if desired for dates that are prior to the Gregorian
    changeover and which fall between January 1 and March 24.
    
    <h2><a id="week_and_year">Week Of Year and Week Year</a></h2>
    
    Values calculated for the Calendar.WEEK_OF_YEAR
    WEEK_OF_YEAR field range from 1 to 53. The first week of a
    calendar year is the earliest seven day period starting on Calendar.getFirstDayOfWeek() getFirstDayOfWeek() that contains at
    least Calendar.getMinimalDaysInFirstWeek()
    getMinimalDaysInFirstWeek() days from that year. It thus depends
    on the values of `getMinimalDaysInFirstWeek()`, `getFirstDayOfWeek()`, and the day of the week of January 1. Weeks
    between week 1 of one year and week 1 of the following year
    (exclusive) are numbered sequentially from 2 to 52 or 53 (except
    for year(s) involved in the Julian-Gregorian transition).
    
    The `getFirstDayOfWeek()` and `getMinimalDaysInFirstWeek()` values are initialized using
    locale-dependent resources when constructing a `GregorianCalendar`. <a id="iso8601_compatible_setting">The week
    determination is compatible</a> with the ISO 8601 standard when `getFirstDayOfWeek()` is `MONDAY` and `getMinimalDaysInFirstWeek()` is 4, which values are used in locales
    where the standard is preferred. These values can explicitly be set by
    calling Calendar.setFirstDayOfWeek(int) setFirstDayOfWeek() and
    Calendar.setMinimalDaysInFirstWeek(int)
    setMinimalDaysInFirstWeek().
    
    A <a id="week_year">*week year*</a> is in sync with a
    `WEEK_OF_YEAR` cycle. All weeks between the first and last
    weeks (inclusive) have the same *week year* value.
    Therefore, the first and last days of a week year may have
    different calendar year values.
    
    For example, January 1, 1998 is a Thursday. If `getFirstDayOfWeek()` is `MONDAY` and `getMinimalDaysInFirstWeek()` is 4 (ISO 8601 standard compatible
    setting), then week 1 of 1998 starts on December 29, 1997, and ends
    on January 4, 1998. The week year is 1998 for the last three days
    of calendar year 1997. If, however, `getFirstDayOfWeek()` is
    `SUNDAY`, then week 1 of 1998 starts on January 4, 1998, and
    ends on January 10, 1998; the first three days of 1998 then are
    part of week 53 of 1997 and their week year is 1997.
    
    <h3>Week Of Month</h3>
    
    Values calculated for the `WEEK_OF_MONTH` field range from 0
    to 6.  Week 1 of a month (the days with `WEEK_OF_MONTH =
    1`) is the earliest set of at least
    `getMinimalDaysInFirstWeek()` contiguous days in that month,
    ending on the day before `getFirstDayOfWeek()`.  Unlike
    week 1 of a year, week 1 of a month may be shorter than 7 days, need
    not start on `getFirstDayOfWeek()`, and will not include days of
    the previous month.  Days of a month before week 1 have a
    `WEEK_OF_MONTH` of 0.
    
    For example, if `getFirstDayOfWeek()` is `SUNDAY`
    and `getMinimalDaysInFirstWeek()` is 4, then the first week of
    January 1998 is Sunday, January 4 through Saturday, January 10.  These days
    have a `WEEK_OF_MONTH` of 1.  Thursday, January 1 through
    Saturday, January 3 have a `WEEK_OF_MONTH` of 0.  If
    `getMinimalDaysInFirstWeek()` is changed to 3, then January 1
    through January 3 have a `WEEK_OF_MONTH` of 1.
    
    <h3>Default Fields Values</h3>
    
    The `clear` method sets calendar field(s)
    undefined. `GregorianCalendar` uses the following
    default value for each calendar field if its value is undefined.
    
    <table class="striped" style="text-align: left; width: 66%;">
    <caption style="display:none">GregorianCalendar default field values</caption>
      <thead>
        <tr>
          <th scope="col">
             Field
          </th>
          <th scope="col">
             Default Value
          </th>
        </tr>
      </thead>
      <tbody>
        <tr>
          <th scope="row">
                 `ERA`
          </th>
          <td>
                 `AD`
          </td>
        </tr>
        <tr>
          <th scope="row">
                 `YEAR`
          </th>
          <td>
                 `1970`
          </td>
        </tr>
        <tr>
          <th scope="row">
                 `MONTH`
          </th>
          <td>
                 `JANUARY`
          </td>
        </tr>
        <tr>
          <th scope="row">
                 `DAY_OF_MONTH`
          </th>
          <td>
                 `1`
          </td>
        </tr>
        <tr>
          <th scope="row">
                 `DAY_OF_WEEK`
          </th>
          <td>
                 `the first day of week`
          </td>
        </tr>
        <tr>
          <th scope="row">
                 `WEEK_OF_MONTH`
          </th>
          <td>
                 `0`
          </td>
        </tr>
        <tr>
          <th scope="row">
                 `DAY_OF_WEEK_IN_MONTH`
          </th>
          <td>
                 `1`
          </td>
        </tr>
        <tr>
          <th scope="row">
                 `AM_PM`
          </th>
          <td>
                 `AM`
          </td>
        </tr>
        <tr>
          <th scope="row">
                 `HOUR, HOUR_OF_DAY, MINUTE, SECOND, MILLISECOND`
          </th>
          <td>
                 `0`
          </td>
        </tr>
      </tbody>
    </table>
    Default values are not applicable for the fields not listed above.
    
    
    <strong>Example:</strong>
    <blockquote>
    ```
    // get the supported ids for GMT-08:00 (Pacific Standard Time)
    String[] ids = TimeZone.getAvailableIDs(-8 * 60 * 60 * 1000);
    // if no ids were returned, something is wrong. get out.
    if (ids.length == 0)
        System.exit(0);
    
     // begin output
    System.out.println("Current Time");
    
    // create a Pacific Standard Time time zone
    SimpleTimeZone pdt = new SimpleTimeZone(-8 * 60 * 60 * 1000, ids[0]);
    
    // set up rules for Daylight Saving Time
    pdt.setStartRule(Calendar.APRIL, 1, Calendar.SUNDAY, 2 * 60 * 60 * 1000);
    pdt.setEndRule(Calendar.OCTOBER, -1, Calendar.SUNDAY, 2 * 60 * 60 * 1000);
    
    // create a GregorianCalendar with the Pacific Daylight time zone
    // and the current date and time
    Calendar calendar = new GregorianCalendar(pdt);
    Date trialTime = new Date();
    calendar.setTime(trialTime);
    
    // print out a bunch of interesting things
    System.out.println("ERA: " + calendar.get(Calendar.ERA));
    System.out.println("YEAR: " + calendar.get(Calendar.YEAR));
    System.out.println("MONTH: " + calendar.get(Calendar.MONTH));
    System.out.println("WEEK_OF_YEAR: " + calendar.get(Calendar.WEEK_OF_YEAR));
    System.out.println("WEEK_OF_MONTH: " + calendar.get(Calendar.WEEK_OF_MONTH));
    System.out.println("DATE: " + calendar.get(Calendar.DATE));
    System.out.println("DAY_OF_MONTH: " + calendar.get(Calendar.DAY_OF_MONTH));
    System.out.println("DAY_OF_YEAR: " + calendar.get(Calendar.DAY_OF_YEAR));
    System.out.println("DAY_OF_WEEK: " + calendar.get(Calendar.DAY_OF_WEEK));
    System.out.println("DAY_OF_WEEK_IN_MONTH: "
                       + calendar.get(Calendar.DAY_OF_WEEK_IN_MONTH));
    System.out.println("AM_PM: " + calendar.get(Calendar.AM_PM));
    System.out.println("HOUR: " + calendar.get(Calendar.HOUR));
    System.out.println("HOUR_OF_DAY: " + calendar.get(Calendar.HOUR_OF_DAY));
    System.out.println("MINUTE: " + calendar.get(Calendar.MINUTE));
    System.out.println("SECOND: " + calendar.get(Calendar.SECOND));
    System.out.println("MILLISECOND: " + calendar.get(Calendar.MILLISECOND));
    System.out.println("ZONE_OFFSET: "
                       + (calendar.get(Calendar.ZONE_OFFSET)/(60*60*1000)));
    System.out.println("DST_OFFSET: "
                       + (calendar.get(Calendar.DST_OFFSET)/(60*60*1000)));
    System.out.println("Current Time, with hour reset to 3");
    calendar.clear(Calendar.HOUR_OF_DAY); // so doesn't override
    calendar.set(Calendar.HOUR, 3);
    System.out.println("ERA: " + calendar.get(Calendar.ERA));
    System.out.println("YEAR: " + calendar.get(Calendar.YEAR));
    System.out.println("MONTH: " + calendar.get(Calendar.MONTH));
    System.out.println("WEEK_OF_YEAR: " + calendar.get(Calendar.WEEK_OF_YEAR));
    System.out.println("WEEK_OF_MONTH: " + calendar.get(Calendar.WEEK_OF_MONTH));
    System.out.println("DATE: " + calendar.get(Calendar.DATE));
    System.out.println("DAY_OF_MONTH: " + calendar.get(Calendar.DAY_OF_MONTH));
    System.out.println("DAY_OF_YEAR: " + calendar.get(Calendar.DAY_OF_YEAR));
    System.out.println("DAY_OF_WEEK: " + calendar.get(Calendar.DAY_OF_WEEK));
    System.out.println("DAY_OF_WEEK_IN_MONTH: "
                       + calendar.get(Calendar.DAY_OF_WEEK_IN_MONTH));
    System.out.println("AM_PM: " + calendar.get(Calendar.AM_PM));
    System.out.println("HOUR: " + calendar.get(Calendar.HOUR));
    System.out.println("HOUR_OF_DAY: " + calendar.get(Calendar.HOUR_OF_DAY));
    System.out.println("MINUTE: " + calendar.get(Calendar.MINUTE));
    System.out.println("SECOND: " + calendar.get(Calendar.SECOND));
    System.out.println("MILLISECOND: " + calendar.get(Calendar.MILLISECOND));
    System.out.println("ZONE_OFFSET: "
           + (calendar.get(Calendar.ZONE_OFFSET)/(60*60*1000))); // in hours
    System.out.println("DST_OFFSET: "
           + (calendar.get(Calendar.DST_OFFSET)/(60*60*1000))); // in hours
    ```
    </blockquote>

    Author(s)
    - David Goldsmith, Mark Davis, Chen-Lieh Huang, Alan Liu

    See
    - TimeZone

    Since
    - 1.1
    """

    BC = 0
    """
    Value of the `ERA` field indicating
    the period before the common era (before Christ), also known as BCE.
    The sequence of years at the transition from `BC` to `AD` is
    ..., 2 BC, 1 BC, 1 AD, 2 AD,...

    See
    - .ERA
    """
    AD = 1
    """
    Value of the `ERA` field indicating
    the common era (Anno Domini), also known as CE.
    The sequence of years at the transition from `BC` to `AD` is
    ..., 2 BC, 1 BC, 1 AD, 2 AD,...

    See
    - .ERA
    """


    def __init__(self):
        """
        Constructs a default `GregorianCalendar` using the current time
        in the default time zone with the default
        Locale.Category.FORMAT FORMAT locale.
        """
        ...


    def __init__(self, zone: "TimeZone"):
        """
        Constructs a `GregorianCalendar` based on the current time
        in the given time zone with the default
        Locale.Category.FORMAT FORMAT locale.

        Arguments
        - zone: the given time zone.
        """
        ...


    def __init__(self, aLocale: "Locale"):
        """
        Constructs a `GregorianCalendar` based on the current time
        in the default time zone with the given locale.

        Arguments
        - aLocale: the given locale.
        """
        ...


    def __init__(self, zone: "TimeZone", aLocale: "Locale"):
        """
        Constructs a `GregorianCalendar` based on the current time
        in the given time zone with the given locale.

        Arguments
        - zone: the given time zone.
        - aLocale: the given locale.
        """
        ...


    def __init__(self, year: int, month: int, dayOfMonth: int):
        """
        Constructs a `GregorianCalendar` with the given date set
        in the default time zone with the default locale.

        Arguments
        - year: the value used to set the `YEAR` calendar field in the calendar.
        - month: the value used to set the `MONTH` calendar field in the calendar.
        Month value is 0-based. e.g., 0 for January.
        - dayOfMonth: the value used to set the `DAY_OF_MONTH` calendar field in the calendar.
        """
        ...


    def __init__(self, year: int, month: int, dayOfMonth: int, hourOfDay: int, minute: int):
        """
        Constructs a `GregorianCalendar` with the given date
        and time set for the default time zone with the default locale.

        Arguments
        - year: the value used to set the `YEAR` calendar field in the calendar.
        - month: the value used to set the `MONTH` calendar field in the calendar.
        Month value is 0-based. e.g., 0 for January.
        - dayOfMonth: the value used to set the `DAY_OF_MONTH` calendar field in the calendar.
        - hourOfDay: the value used to set the `HOUR_OF_DAY` calendar field
        in the calendar.
        - minute: the value used to set the `MINUTE` calendar field
        in the calendar.
        """
        ...


    def __init__(self, year: int, month: int, dayOfMonth: int, hourOfDay: int, minute: int, second: int):
        """
        Constructs a GregorianCalendar with the given date
        and time set for the default time zone with the default locale.

        Arguments
        - year: the value used to set the `YEAR` calendar field in the calendar.
        - month: the value used to set the `MONTH` calendar field in the calendar.
        Month value is 0-based. e.g., 0 for January.
        - dayOfMonth: the value used to set the `DAY_OF_MONTH` calendar field in the calendar.
        - hourOfDay: the value used to set the `HOUR_OF_DAY` calendar field
        in the calendar.
        - minute: the value used to set the `MINUTE` calendar field
        in the calendar.
        - second: the value used to set the `SECOND` calendar field
        in the calendar.
        """
        ...


    def setGregorianChange(self, date: "Date") -> None:
        """
        Sets the `GregorianCalendar` change date. This is the point when the switch
        from Julian dates to Gregorian dates occurred. Default is October 15,
        1582 (Gregorian). Previous to this, dates will be in the Julian calendar.
        
        To obtain a pure Julian calendar, set the change date to
        `Date(Long.MAX_VALUE)`.  To obtain a pure Gregorian calendar,
        set the change date to `Date(Long.MIN_VALUE)`.

        Arguments
        - date: the given Gregorian cutover date.
        """
        ...


    def getGregorianChange(self) -> "Date":
        """
        Gets the Gregorian Calendar change date.  This is the point when the
        switch from Julian dates to Gregorian dates occurred. Default is
        October 15, 1582 (Gregorian). Previous to this, dates will be in the Julian
        calendar.

        Returns
        - the Gregorian cutover date for this `GregorianCalendar` object.
        """
        ...


    def isLeapYear(self, year: int) -> bool:
        """
        Determines if the given year is a leap year. Returns `True` if
        the given year is a leap year. To specify BC year numbers,
        `1 - year number` must be given. For example, year BC 4 is
        specified as -3.

        Arguments
        - year: the given year.

        Returns
        - `True` if the given year is a leap year; `False` otherwise.
        """
        ...


    def getCalendarType(self) -> str:
        """
        Returns `"gregory"` as the calendar type.

        Returns
        - `"gregory"`

        Since
        - 1.8
        """
        ...


    def equals(self, obj: "Object") -> bool:
        """
        Compares this `GregorianCalendar` to the specified
        `Object`. The result is `True` if and
        only if the argument is a `GregorianCalendar` object
        that represents the same time value (millisecond offset from
        the <a href="Calendar.html#Epoch">Epoch</a>) under the same
        `Calendar` parameters and Gregorian change date as
        this object.

        Arguments
        - obj: the object to compare with.

        Returns
        - `True` if this object is equal to `obj`;
        `False` otherwise.

        See
        - Calendar.compareTo(Calendar)
        """
        ...


    def hashCode(self) -> int:
        """
        Generates the hash code for this `GregorianCalendar` object.
        """
        ...


    def add(self, field: int, amount: int) -> None:
        """
        Adds the specified (signed) amount of time to the given calendar field,
        based on the calendar's rules.
        
        *Add rule 1*. The value of `field`
        after the call minus the value of `field` before the
        call is `amount`, modulo any overflow that has occurred in
        `field`. Overflow occurs when a field value exceeds its
        range and, as a result, the next larger field is incremented or
        decremented and the field value is adjusted back into its range.
        
        *Add rule 2*. If a smaller field is expected to be
        invariant, but it is impossible for it to be equal to its
        prior value because of changes in its minimum or maximum after
        `field` is changed, then its value is adjusted to be as close
        as possible to its expected value. A smaller field represents a
        smaller unit of time. `HOUR` is a smaller field than
        `DAY_OF_MONTH`. No adjustment is made to smaller fields
        that are not expected to be invariant. The calendar system
        determines what fields are expected to be invariant.

        Arguments
        - field: the calendar field.
        - amount: the amount of date or time to be added to the field.

        Raises
        - IllegalArgumentException: if `field` is
        `ZONE_OFFSET`, `DST_OFFSET`, or unknown,
        or if any calendar fields have out-of-range values in
        non-lenient mode.
        """
        ...


    def roll(self, field: int, up: bool) -> None:
        """
        Adds or subtracts (up/down) a single unit of time on the given time
        field without changing larger fields.
        
        *Example*: Consider a `GregorianCalendar`
        originally set to December 31, 1999. Calling .roll(int,boolean) roll(Calendar.MONTH, True)
        sets the calendar to January 31, 1999.  The `YEAR` field is unchanged
        because it is a larger field than `MONTH`.

        Arguments
        - up: indicates if the value of the specified calendar field is to be
        rolled up or rolled down. Use `True` if rolling up, `False` otherwise.

        Raises
        - IllegalArgumentException: if `field` is
        `ZONE_OFFSET`, `DST_OFFSET`, or unknown,
        or if any calendar fields have out-of-range values in
        non-lenient mode.

        See
        - .set(int,int)
        """
        ...


    def roll(self, field: int, amount: int) -> None:
        """
        Adds a signed amount to the specified calendar field without changing larger fields.
        A negative roll amount means to subtract from field without changing
        larger fields. If the specified amount is 0, this method performs nothing.
        
        This method calls .complete() before adding the
        amount so that all the calendar fields are normalized. If there
        is any calendar field having an out-of-range value in non-lenient mode, then an
        `IllegalArgumentException` is thrown.
        
        
        *Example*: Consider a `GregorianCalendar`
        originally set to August 31, 1999. Calling `roll(Calendar.MONTH,
        8)` sets the calendar to April 30, <strong>1999</strong>. Using a
        `GregorianCalendar`, the `DAY_OF_MONTH` field cannot
        be 31 in the month April. `DAY_OF_MONTH` is set to the closest possible
        value, 30. The `YEAR` field maintains the value of 1999 because it
        is a larger field than `MONTH`.
        
        *Example*: Consider a `GregorianCalendar`
        originally set to Sunday June 6, 1999. Calling
        `roll(Calendar.WEEK_OF_MONTH, -1)` sets the calendar to
        Tuesday June 1, 1999, whereas calling
        `add(Calendar.WEEK_OF_MONTH, -1)` sets the calendar to
        Sunday May 30, 1999. This is because the roll rule imposes an
        additional constraint: The `MONTH` must not change when the
        `WEEK_OF_MONTH` is rolled. Taken together with add rule 1,
        the resultant date must be between Tuesday June 1 and Saturday June
        5. According to add rule 2, the `DAY_OF_WEEK`, an invariant
        when changing the `WEEK_OF_MONTH`, is set to Tuesday, the
        closest possible value to Sunday (where Sunday is the first day of the
        week).

        Arguments
        - field: the calendar field.
        - amount: the signed amount to add to `field`.

        Raises
        - IllegalArgumentException: if `field` is
        `ZONE_OFFSET`, `DST_OFFSET`, or unknown,
        or if any calendar fields have out-of-range values in
        non-lenient mode.

        See
        - .set(int,int)

        Since
        - 1.2
        """
        ...


    def getMinimum(self, field: int) -> int:
        """
        Returns the minimum value for the given calendar field of this
        `GregorianCalendar` instance. The minimum value is
        defined as the smallest value returned by the Calendar.get(int) get method for any possible time value,
        taking into consideration the current values of the
        Calendar.getFirstDayOfWeek() getFirstDayOfWeek,
        Calendar.getMinimalDaysInFirstWeek() getMinimalDaysInFirstWeek,
        .getGregorianChange() getGregorianChange and
        Calendar.getTimeZone() getTimeZone methods.

        Arguments
        - field: the calendar field.

        Returns
        - the minimum value for the given calendar field.

        See
        - .getActualMaximum(int)
        """
        ...


    def getMaximum(self, field: int) -> int:
        """
        Returns the maximum value for the given calendar field of this
        `GregorianCalendar` instance. The maximum value is
        defined as the largest value returned by the Calendar.get(int) get method for any possible time value,
        taking into consideration the current values of the
        Calendar.getFirstDayOfWeek() getFirstDayOfWeek,
        Calendar.getMinimalDaysInFirstWeek() getMinimalDaysInFirstWeek,
        .getGregorianChange() getGregorianChange and
        Calendar.getTimeZone() getTimeZone methods.

        Arguments
        - field: the calendar field.

        Returns
        - the maximum value for the given calendar field.

        See
        - .getActualMaximum(int)
        """
        ...


    def getGreatestMinimum(self, field: int) -> int:
        """
        Returns the highest minimum value for the given calendar field
        of this `GregorianCalendar` instance. The highest
        minimum value is defined as the largest value returned by
        .getActualMinimum(int) for any possible time value,
        taking into consideration the current values of the
        Calendar.getFirstDayOfWeek() getFirstDayOfWeek,
        Calendar.getMinimalDaysInFirstWeek() getMinimalDaysInFirstWeek,
        .getGregorianChange() getGregorianChange and
        Calendar.getTimeZone() getTimeZone methods.

        Arguments
        - field: the calendar field.

        Returns
        - the highest minimum value for the given calendar field.

        See
        - .getActualMaximum(int)
        """
        ...


    def getLeastMaximum(self, field: int) -> int:
        """
        Returns the lowest maximum value for the given calendar field
        of this `GregorianCalendar` instance. The lowest
        maximum value is defined as the smallest value returned by
        .getActualMaximum(int) for any possible time value,
        taking into consideration the current values of the
        Calendar.getFirstDayOfWeek() getFirstDayOfWeek,
        Calendar.getMinimalDaysInFirstWeek() getMinimalDaysInFirstWeek,
        .getGregorianChange() getGregorianChange and
        Calendar.getTimeZone() getTimeZone methods.

        Arguments
        - field: the calendar field

        Returns
        - the lowest maximum value for the given calendar field.

        See
        - .getActualMaximum(int)
        """
        ...


    def getActualMinimum(self, field: int) -> int:
        """
        Returns the minimum value that this calendar field could have,
        taking into consideration the given time value and the current
        values of the
        Calendar.getFirstDayOfWeek() getFirstDayOfWeek,
        Calendar.getMinimalDaysInFirstWeek() getMinimalDaysInFirstWeek,
        .getGregorianChange() getGregorianChange and
        Calendar.getTimeZone() getTimeZone methods.
        
        For example, if the Gregorian change date is January 10,
        1970 and the date of this `GregorianCalendar` is
        January 20, 1970, the actual minimum value of the
        `DAY_OF_MONTH` field is 10 because the previous date
        of January 10, 1970 is December 27, 1996 (in the Julian
        calendar). Therefore, December 28, 1969 to January 9, 1970
        don't exist.

        Arguments
        - field: the calendar field

        Returns
        - the minimum of the given field for the time value of
        this `GregorianCalendar`

        See
        - .getActualMaximum(int)

        Since
        - 1.2
        """
        ...


    def getActualMaximum(self, field: int) -> int:
        """
        Returns the maximum value that this calendar field could have,
        taking into consideration the given time value and the current
        values of the
        Calendar.getFirstDayOfWeek() getFirstDayOfWeek,
        Calendar.getMinimalDaysInFirstWeek() getMinimalDaysInFirstWeek,
        .getGregorianChange() getGregorianChange and
        Calendar.getTimeZone() getTimeZone methods.
        For example, if the date of this instance is February 1, 2004,
        the actual maximum value of the `DAY_OF_MONTH` field
        is 29 because 2004 is a leap year, and if the date of this
        instance is February 1, 2005, it's 28.
        
        This method calculates the maximum value of Calendar.WEEK_OF_YEAR WEEK_OF_YEAR based on the Calendar.YEAR YEAR (calendar year) value, not the <a
        href="#week_year">week year</a>. Call .getWeeksInWeekYear() to get the maximum value of `WEEK_OF_YEAR` in the week year of this `GregorianCalendar`.

        Arguments
        - field: the calendar field

        Returns
        - the maximum of the given field for the time value of
        this `GregorianCalendar`

        See
        - .getActualMinimum(int)

        Since
        - 1.2
        """
        ...


    def clone(self) -> "Object":
        ...


    def getTimeZone(self) -> "TimeZone":
        ...


    def setTimeZone(self, zone: "TimeZone") -> None:
        ...


    def isWeekDateSupported(self) -> bool:
        """
        Returns `True` indicating this `GregorianCalendar`
        supports week dates.

        Returns
        - `True` (always)

        See
        - .getWeeksInWeekYear()

        Since
        - 1.7
        """
        ...


    def getWeekYear(self) -> int:
        """
        Returns the <a href="#week_year">week year</a> represented by this
        `GregorianCalendar`. The dates in the weeks between 1 and the
        maximum week number of the week year have the same week year value
        that may be one year before or after the Calendar.YEAR YEAR
        (calendar year) value.
        
        This method calls Calendar.complete() before
        calculating the week year.

        Returns
        - the week year represented by this `GregorianCalendar`.
                If the Calendar.ERA ERA value is .BC, the year is
                represented by 0 or a negative number: BC 1 is 0, BC 2
                is -1, BC 3 is -2, and so on.

        Raises
        - IllegalArgumentException: if any of the calendar fields is invalid in non-lenient mode.

        See
        - Calendar.getMinimalDaysInFirstWeek()

        Since
        - 1.7
        """
        ...


    def setWeekDate(self, weekYear: int, weekOfYear: int, dayOfWeek: int) -> None:
        """
        Sets this `GregorianCalendar` to the date given by the
        date specifiers - <a href="#week_year">`weekYear`</a>,
        `weekOfYear`, and `dayOfWeek`. `weekOfYear`
        follows the <a href="#week_and_year">`WEEK_OF_YEAR`
        numbering</a>.  The `dayOfWeek` value must be one of the
        Calendar.DAY_OF_WEEK DAY_OF_WEEK values: Calendar.SUNDAY SUNDAY to Calendar.SATURDAY SATURDAY.
        
        Note that the numeric day-of-week representation differs from
        the ISO 8601 standard, and that the `weekOfYear`
        numbering is compatible with the standard when `getFirstDayOfWeek()` is `MONDAY` and `getMinimalDaysInFirstWeek()` is 4.
        
        Unlike the `set` method, all of the calendar fields
        and the instant of time value are calculated upon return.
        
        If `weekOfYear` is out of the valid week-of-year
        range in `weekYear`, the `weekYear`
        and `weekOfYear` values are adjusted in lenient
        mode, or an `IllegalArgumentException` is thrown in
        non-lenient mode.

        Arguments
        - weekYear: the week year
        - weekOfYear: the week number based on `weekYear`
        - dayOfWeek: the day of week value: one of the constants
                           for the .DAY_OF_WEEK DAY_OF_WEEK field:
                           Calendar.SUNDAY SUNDAY, ...,
                           Calendar.SATURDAY SATURDAY.

        Raises
        - IllegalArgumentException: if any of the given date specifiers is invalid,
                   or if any of the calendar fields are inconsistent
                   with the given date specifiers in non-lenient mode

        See
        - Calendar.getMinimalDaysInFirstWeek()

        Since
        - 1.7
        """
        ...


    def getWeeksInWeekYear(self) -> int:
        """
        Returns the number of weeks in the <a href="#week_year">week year</a>
        represented by this `GregorianCalendar`.
        
        For example, if this `GregorianCalendar`'s date is
        December 31, 2008 with <a href="#iso8601_compatible_setting">the ISO
        8601 compatible setting</a>, this method will return 53 for the
        period: December 29, 2008 to January 3, 2010 while .getActualMaximum(int) getActualMaximum(WEEK_OF_YEAR) will return
        52 for the period: December 31, 2007 to December 28, 2008.

        Returns
        - the number of weeks in the week year.

        See
        - .getActualMaximum(int)

        Since
        - 1.7
        """
        ...


    def toZonedDateTime(self) -> "ZonedDateTime":
        """
        Converts this object to a `ZonedDateTime` that represents
        the same point on the time-line as this `GregorianCalendar`.
        
        Since this object supports a Julian-Gregorian cutover date and
        `ZonedDateTime` does not, it is possible that the resulting year,
        month and day will have different values.  The result will represent the
        correct date in the ISO calendar system, which will also be the same value
        for Modified Julian Days.

        Returns
        - a zoned date-time representing the same point on the time-line
         as this gregorian calendar

        Since
        - 1.8
        """
        ...


    @staticmethod
    def from(zdt: "ZonedDateTime") -> "GregorianCalendar":
        """
        Obtains an instance of `GregorianCalendar` with the default locale
        from a `ZonedDateTime` object.
        
        Since `ZonedDateTime` does not support a Julian-Gregorian cutover
        date and uses ISO calendar system, the return GregorianCalendar is a pure
        Gregorian calendar and uses ISO 8601 standard for week definitions,
        which has `MONDAY` as the Calendar.getFirstDayOfWeek()
        FirstDayOfWeek and `4` as the value of the
        Calendar.getMinimalDaysInFirstWeek() MinimalDaysInFirstWeek.
        
        `ZoneDateTime` can store points on the time-line further in the
        future and further in the past than `GregorianCalendar`. In this
        scenario, this method will throw an `IllegalArgumentException`
        exception.

        Arguments
        - zdt: the zoned date-time object to convert

        Returns
        - the gregorian calendar representing the same point on the
         time-line as the zoned date-time provided

        Raises
        - NullPointerException: if `zdt` is null
        - IllegalArgumentException: if the zoned date-time is too
        large to represent as a `GregorianCalendar`

        Since
        - 1.8
        """
        ...



"""
Python module generated from Java source file org.bukkit.enchantments.EnchantmentTarget

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import Material
from org.bukkit.enchantments import *
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class EnchantmentTarget(Enum):
    """
    Represents the applicable target for a Enchantment
    """

    ALL = 0
    """
    Allows the Enchantment to be placed on all items

    Deprecated
    - this target no longer exists in Vanilla
    """
    ARMOR = 1
    """
    Allows the Enchantment to be placed on armor
    """
    ARMOR_FEET = 2
    """
    Allows the Enchantment to be placed on feet slot armor
    """
    ARMOR_LEGS = 3
    """
    Allows the Enchantment to be placed on leg slot armor
    """
    ARMOR_TORSO = 4
    """
    Allows the Enchantment to be placed on torso slot armor
    """
    ARMOR_HEAD = 5
    """
    Allows the Enchantment to be placed on head slot armor
    """
    WEAPON = 6
    """
    Allows the Enchantment to be placed on weapons (swords)
    """
    TOOL = 7
    """
    Allows the Enchantment to be placed on tools (spades, pickaxe, axes)
    """
    BOW = 8
    """
    Allows the Enchantment to be placed on bows.
    """
    FISHING_ROD = 9
    """
    Allows the Enchantment to be placed on fishing rods.
    """
    BREAKABLE = 10
    """
    Allows the enchantment to be placed on items with durability.
    """
    WEARABLE = 11
    """
    Allows the enchantment to be placed on wearable items.
    """
    TRIDENT = 12
    """
    Allow the Enchantment to be placed on tridents.
    """
    CROSSBOW = 13
    """
    Allow the Enchantment to be placed on crossbows.
    """
    VANISHABLE = 14
    """
    Allow the Enchantment to be placed on vanishing items.
    """


    def includes(self, item: "Material") -> bool:
        """
        Check whether this target includes the specified item.

        Arguments
        - item: The item to check

        Returns
        - True if the target includes the item
        """
        ...


    def includes(self, item: "ItemStack") -> bool:
        """
        Check whether this target includes the specified item.

        Arguments
        - item: The item to check

        Returns
        - True if the target includes the item
        """
        ...



"""
Python module generated from Java source file com.google.gson.JsonPrimitive

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from com.google.gson.internal import LazilyParsedNumber
from com.google.gson.internal import NumberLimits
from java.math import BigDecimal
from java.math import BigInteger
from java.util import Objects
from typing import Any, Callable, Iterable, Tuple


class JsonPrimitive(JsonElement):
    """
    A class representing a JSON primitive value. A primitive value is either a String, a Java
    primitive, or a Java primitive wrapper type.
    
    See the JsonElement documentation for details on how to convert `JsonPrimitive`
    and generally any `JsonElement` from and to JSON.

    Author(s)
    - Joel Leitch
    """

    def __init__(self, bool: "Boolean"):
        ...


    def __init__(self, number: "Number"):
        """
        Create a primitive containing a Number.

        Arguments
        - number: the value to create the primitive with.
        """
        ...


    def __init__(self, string: str):
        """
        Create a primitive containing a String value.

        Arguments
        - string: the value to create the primitive with.
        """
        ...


    def __init__(self, c: "Character"):
        ...


    def deepCopy(self) -> "JsonPrimitive":
        """
        Returns the same value as primitives are immutable.

        Since
        - 2.8.2
        """
        ...


    def isBoolean(self) -> bool:
        """
        Check whether this primitive contains a boolean value.

        Returns
        - True if this primitive contains a boolean value, False otherwise.
        """
        ...


    def getAsBoolean(self) -> bool:
        """
        Convenience method to get this element as a boolean value. If this primitive .isBoolean() is not a boolean, the string value is parsed using Boolean.parseBoolean(String). This means `"True"` (ignoring case) is considered `True` and any other value is considered `False`.
        """
        ...


    def isNumber(self) -> bool:
        """
        Check whether this primitive contains a Number.

        Returns
        - True if this primitive contains a Number, False otherwise.
        """
        ...


    def getAsNumber(self) -> "Number":
        """
        Convenience method to get this element as a Number. If this primitive .isString() is a string, a lazily parsed `Number` is constructed which parses the string
        when any of its methods are called (which can lead to a NumberFormatException).

        Raises
        - UnsupportedOperationException: if this primitive is neither a number nor a string.
        """
        ...


    def isString(self) -> bool:
        """
        Check whether this primitive contains a String value.

        Returns
        - True if this primitive contains a String value, False otherwise.
        """
        ...


    def getAsString(self) -> str:
        ...


    def getAsDouble(self) -> float:
        """
        Raises
        - NumberFormatException: 
        """
        ...


    def getAsBigDecimal(self) -> "BigDecimal":
        """
        Raises
        - NumberFormatException: 
        """
        ...


    def getAsBigInteger(self) -> "BigInteger":
        """
        Raises
        - NumberFormatException: 
        """
        ...


    def getAsFloat(self) -> float:
        """
        Raises
        - NumberFormatException: 
        """
        ...


    def getAsLong(self) -> int:
        """
        Convenience method to get this element as a primitive long.

        Returns
        - this element as a primitive long.

        Raises
        - NumberFormatException: 
        """
        ...


    def getAsShort(self) -> int:
        """
        Raises
        - NumberFormatException: 
        """
        ...


    def getAsInt(self) -> int:
        """
        Raises
        - NumberFormatException: 
        """
        ...


    def getAsByte(self) -> int:
        """
        Raises
        - NumberFormatException: 
        """
        ...


    def getAsCharacter(self) -> str:
        """
        Raises
        - UnsupportedOperationException: if the string value of this primitive is empty.

        Deprecated
        - This method is misleading, as it does not get this element as a char but rather as
            a string's first character.
        """
        ...


    def hashCode(self) -> int:
        """
        Returns the hash code of this object.
        """
        ...


    def equals(self, obj: "Object") -> bool:
        """
        Returns whether the other object is equal to this. This method only considers the other object
        to be equal if it is an instance of `JsonPrimitive` and has an equal value.
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ArrayListMultimap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.collect import *
from java.io import IOException
from java.io import ObjectInputStream
from java.io import ObjectOutputStream
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ArrayListMultimap(ArrayListMultimapGwtSerializationDependencies):
    """
    Implementation of `Multimap` that uses an `ArrayList` to store the values for a given
    key. A HashMap associates each key with an ArrayList of values.
    
    When iterating through the collections supplied by this class, the ordering of values for a
    given key agrees with the order in which the values were added.
    
    This multimap allows duplicate key-value pairs. After adding a new key-value pair equal to an
    existing key-value pair, the `ArrayListMultimap` will contain entries for both the new
    value and the old value.
    
    Keys and values may be null. All optional multimap methods are supported, and all returned
    views are modifiable.
    
    The lists returned by .get, .removeAll, and .replaceValues all
    implement java.util.RandomAccess.
    
    This class is not threadsafe when any concurrent operations update the multimap. Concurrent
    read operations will work correctly. To allow concurrent update operations, wrap your multimap
    with a call to Multimaps.synchronizedListMultimap.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/NewCollectionTypesExplained#multimap">`Multimap`</a>.

    Author(s)
    - Jared Levy

    Since
    - 2.0
    """

    @staticmethod
    def create() -> "ArrayListMultimap"["K", "V"]:
        """
        Creates a new, empty `ArrayListMultimap` with the default initial capacities.
        
        You may also consider the equivalent `MultimapBuilder.hashKeys().arrayListValues().build()`, which provides more control over the
        underlying data structure.
        """
        ...


    @staticmethod
    def create(expectedKeys: int, expectedValuesPerKey: int) -> "ArrayListMultimap"["K", "V"]:
        """
        Constructs an empty `ArrayListMultimap` with enough capacity to hold the specified
        numbers of keys and values without resizing.
        
        You may also consider the equivalent `MultimapBuilder.hashKeys(expectedKeys).arrayListValues(expectedValuesPerKey).build()`, which
        provides more control over the underlying data structure.

        Arguments
        - expectedKeys: the expected number of distinct keys
        - expectedValuesPerKey: the expected average number of values per key

        Raises
        - IllegalArgumentException: if `expectedKeys` or `expectedValuesPerKey` is
            negative
        """
        ...


    @staticmethod
    def create(multimap: "Multimap"["K", "V"]) -> "ArrayListMultimap"["K", "V"]:
        """
        Constructs an `ArrayListMultimap` with the same mappings as the specified multimap.
        
        You may also consider the equivalent `MultimapBuilder.hashKeys().arrayListValues().build(multimap)`, which provides more control over
        the underlying data structure.

        Arguments
        - multimap: the multimap whose contents are copied to this multimap
        """
        ...


    def trimToSize(self) -> None:
        """
        Reduces the memory used by this `ArrayListMultimap`, if feasible.

        Deprecated
        - For a ListMultimap that automatically trims to size, use ImmutableListMultimap. If you need a mutable collection, remove the `trimToSize`
            call, or switch to a `HashMap<K, ArrayList<V>>`.
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ImmutableMultiset

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import DoNotCall
from com.google.errorprone.annotations.concurrent import LazyInit
from com.google.j2objc.annotations import WeakOuter
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import Serializable
from java.util import Arrays
from java.util import Collections
from java.util import Iterator
from java.util.function import Function
from java.util.function import ToIntFunction
from java.util.stream import Collector
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ImmutableMultiset(ImmutableMultisetGwtSerializationDependencies, Multiset):
    """
    A Multiset whose contents will never change, with many other important properties
    detailed at ImmutableCollection.
    
    **Grouped iteration.** In all current implementations, duplicate elements always appear
    consecutively when iterating. Elements iterate in order by the *first* appearance of that
    element when the multiset was created.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/ImmutableCollectionsExplained">immutable collections</a>.

    Author(s)
    - Louis Wasserman

    Since
    - 2.0
    """

    @staticmethod
    def toImmutableMultiset() -> "Collector"["E", Any, "ImmutableMultiset"["E"]]:
        """
        Returns a `Collector` that accumulates the input elements into a new `ImmutableMultiset`. Elements iterate in order by the *first* appearance of that element in
        encounter order.

        Since
        - 21.0
        """
        ...


    @staticmethod
    def toImmutableMultiset(elementFunction: "Function"["T", "E"], countFunction: "ToIntFunction"["T"]) -> "Collector"["T", Any, "ImmutableMultiset"["E"]]:
        """
        Returns a `Collector` that accumulates elements into an `ImmutableMultiset` whose
        elements are the result of applying `elementFunction` to the inputs, with counts equal to
        the result of applying `countFunction` to the inputs.
        
        If the mapped elements contain duplicates (according to Object.equals), the first
        occurrence in encounter order appears in the resulting multiset, with count equal to the sum of
        the outputs of `countFunction.applyAsInt(t)` for each `t` mapped to that element.

        Since
        - 22.0
        """
        ...


    @staticmethod
    def of() -> "ImmutableMultiset"["E"]:
        """
        Returns the empty immutable multiset.
        
        **Performance note:** the instance returned is a singleton.
        """
        ...


    @staticmethod
    def of(e1: "E") -> "ImmutableMultiset"["E"]:
        """
        Returns an immutable multiset containing a single element.

        Raises
        - NullPointerException: if the element is null

        Since
        - 6.0 (source-compatible since 2.0)
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E") -> "ImmutableMultiset"["E"]:
        """
        Returns an immutable multiset containing the given elements, in order.

        Raises
        - NullPointerException: if any element is null

        Since
        - 6.0 (source-compatible since 2.0)
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E") -> "ImmutableMultiset"["E"]:
        """
        Returns an immutable multiset containing the given elements, in the "grouped iteration order"
        described in the class documentation.

        Raises
        - NullPointerException: if any element is null

        Since
        - 6.0 (source-compatible since 2.0)
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E") -> "ImmutableMultiset"["E"]:
        """
        Returns an immutable multiset containing the given elements, in the "grouped iteration order"
        described in the class documentation.

        Raises
        - NullPointerException: if any element is null

        Since
        - 6.0 (source-compatible since 2.0)
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E", e5: "E") -> "ImmutableMultiset"["E"]:
        """
        Returns an immutable multiset containing the given elements, in the "grouped iteration order"
        described in the class documentation.

        Raises
        - NullPointerException: if any element is null

        Since
        - 6.0 (source-compatible since 2.0)
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E", e5: "E", e6: "E", *others: Tuple["E", ...]) -> "ImmutableMultiset"["E"]:
        """
        Returns an immutable multiset containing the given elements, in the "grouped iteration order"
        described in the class documentation.

        Raises
        - NullPointerException: if any element is null

        Since
        - 6.0 (source-compatible since 2.0)
        """
        ...


    @staticmethod
    def copyOf(elements: list["E"]) -> "ImmutableMultiset"["E"]:
        """
        Returns an immutable multiset containing the given elements, in the "grouped iteration order"
        described in the class documentation.

        Raises
        - NullPointerException: if any of `elements` is null

        Since
        - 6.0
        """
        ...


    @staticmethod
    def copyOf(elements: Iterable["E"]) -> "ImmutableMultiset"["E"]:
        """
        Returns an immutable multiset containing the given elements, in the "grouped iteration order"
        described in the class documentation.

        Raises
        - NullPointerException: if any of `elements` is null
        """
        ...


    @staticmethod
    def copyOf(elements: Iterator["E"]) -> "ImmutableMultiset"["E"]:
        """
        Returns an immutable multiset containing the given elements, in the "grouped iteration order"
        described in the class documentation.

        Raises
        - NullPointerException: if any of `elements` is null
        """
        ...


    def iterator(self) -> "UnmodifiableIterator"["E"]:
        ...


    def asList(self) -> "ImmutableList"["E"]:
        ...


    def contains(self, object: "Object") -> bool:
        ...


    def add(self, element: "E", occurrences: int) -> int:
        """
        Guaranteed to throw an exception and leave the collection unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def remove(self, element: "Object", occurrences: int) -> int:
        """
        Guaranteed to throw an exception and leave the collection unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def setCount(self, element: "E", count: int) -> int:
        """
        Guaranteed to throw an exception and leave the collection unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def setCount(self, element: "E", oldCount: int, newCount: int) -> bool:
        """
        Guaranteed to throw an exception and leave the collection unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def equals(self, object: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...


    def toString(self) -> str:
        ...


    def elementSet(self) -> "ImmutableSet"["E"]:
        """
        Since
        - 21.0 (present with return type `Set` since 2.0)
        """
        ...


    def entrySet(self) -> "ImmutableSet"["Entry"["E"]]:
        ...


    @staticmethod
    def builder() -> "Builder"["E"]:
        """
        Returns a new builder. The generated builder is equivalent to the builder created by the Builder constructor.
        """
        ...


    class Builder(Builder):
        """
        A builder for creating immutable multiset instances, especially `public static final`
        multisets ("constant multisets"). Example:
        
        ````public static final ImmutableMultiset<Bean> BEANS =
            new ImmutableMultiset.Builder<Bean>()
                .addCopies(Bean.COCOA, 4)
                .addCopies(Bean.GARDEN, 6)
                .addCopies(Bean.RED, 8)
                .addCopies(Bean.BLACK_EYED, 10)
                .build();````
        
        Builder instances can be reused; it is safe to call .build multiple times to build
        multiple multisets in series.

        Since
        - 2.0
        """

        def __init__(self):
            """
            Creates a new builder. The returned builder is equivalent to the builder generated by ImmutableMultiset.builder.
            """
            ...


        def add(self, element: "E") -> "Builder"["E"]:
            """
            Adds `element` to the `ImmutableMultiset`.

            Arguments
            - element: the element to add

            Returns
            - this `Builder` object

            Raises
            - NullPointerException: if `element` is null
            """
            ...


        def add(self, *elements: Tuple["E", ...]) -> "Builder"["E"]:
            """
            Adds each element of `elements` to the `ImmutableMultiset`.

            Arguments
            - elements: the elements to add

            Returns
            - this `Builder` object

            Raises
            - NullPointerException: if `elements` is null or contains a null element
            """
            ...


        def addCopies(self, element: "E", occurrences: int) -> "Builder"["E"]:
            """
            Adds a number of occurrences of an element to this `ImmutableMultiset`.

            Arguments
            - element: the element to add
            - occurrences: the number of occurrences of the element to add. May be zero, in which
                case no change will be made.

            Returns
            - this `Builder` object

            Raises
            - NullPointerException: if `element` is null
            - IllegalArgumentException: if `occurrences` is negative, or if this operation
                would result in more than Integer.MAX_VALUE occurrences of the element
            """
            ...


        def setCount(self, element: "E", count: int) -> "Builder"["E"]:
            """
            Adds or removes the necessary occurrences of an element such that the element attains the
            desired count.

            Arguments
            - element: the element to add or remove occurrences of
            - count: the desired count of the element in this multiset

            Returns
            - this `Builder` object

            Raises
            - NullPointerException: if `element` is null
            - IllegalArgumentException: if `count` is negative
            """
            ...


        def addAll(self, elements: Iterable["E"]) -> "Builder"["E"]:
            """
            Adds each element of `elements` to the `ImmutableMultiset`.

            Arguments
            - elements: the `Iterable` to add to the `ImmutableMultiset`

            Returns
            - this `Builder` object

            Raises
            - NullPointerException: if `elements` is null or contains a null element
            """
            ...


        def addAll(self, elements: Iterator["E"]) -> "Builder"["E"]:
            """
            Adds each element of `elements` to the `ImmutableMultiset`.

            Arguments
            - elements: the elements to add to the `ImmutableMultiset`

            Returns
            - this `Builder` object

            Raises
            - NullPointerException: if `elements` is null or contains a null element
            """
            ...


        def build(self) -> "ImmutableMultiset"["E"]:
            """
            Returns a newly-created `ImmutableMultiset` based on the contents of the `Builder`.
            """
            ...



"""
Python module generated from Java source file org.bukkit.block.data.type.Crafter

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block.data import BlockData
from org.bukkit.block.data import Powerable
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class Crafter(BlockData):
    """
    'orientation' is the direction the block is facing.
    
    Similar to Powerable, 'triggered' indicates whether or not the
    dispenser is currently activated.
    
    'crafting' is whether crafter's mouth is open and top is glowing.
    """

    def isCrafting(self) -> bool:
        """
        Gets the value of the 'crafting' property.

        Returns
        - the 'crafting' value
        """
        ...


    def setCrafting(self, crafting: bool) -> None:
        """
        Sets the value of the 'crafting' property.

        Arguments
        - crafting: the new 'crafting' value
        """
        ...


    def isTriggered(self) -> bool:
        """
        Gets the value of the 'triggered' property.

        Returns
        - the 'triggered' value
        """
        ...


    def setTriggered(self, triggered: bool) -> None:
        """
        Sets the value of the 'triggered' property.

        Arguments
        - triggered: the new 'triggered' value
        """
        ...


    def getOrientation(self) -> "Orientation":
        """
        Gets the value of the 'orientation' property.

        Returns
        - the 'orientation' value
        """
        ...


    def setOrientation(self, orientation: "Orientation") -> None:
        """
        Sets the value of the 'orientation' property.

        Arguments
        - orientation: the new 'orientation' value
        """
        ...


    class Orientation(Enum):
        """
        The directions the Crafter can be oriented.
        """

        DOWN_EAST = 0
        DOWN_NORTH = 1
        DOWN_SOUTH = 2
        DOWN_WEST = 3
        UP_EAST = 4
        UP_NORTH = 5
        UP_SOUTH = 6
        UP_WEST = 7
        WEST_UP = 8
        EAST_UP = 9
        NORTH_UP = 10
        SOUTH_UP = 11



"""
Python module generated from Java source file org.yaml.snakeyaml.external.com.google.gdata.util.common.base.UnicodeEscaper

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import IOException
from org.yaml.snakeyaml.external.com.google.gdata.util.common.base import *
from typing import Any, Callable, Iterable, Tuple


class UnicodeEscaper(Escaper):
    """
    An Escaper that converts literal text into a format safe for inclusion in a particular
    context (such as an XML document). Typically (but not always), the inverse process of
    "unescaping" the text is performed automatically by the relevant parser.
    
    
    For example, an XML escaper would convert the literal string `"Foo<Bar>"` into
    `"Foo&lt;Bar&gt;"` to prevent `"<Bar>"` from being confused with an XML tag. When the
    resulting XML document is parsed, the parser API will return this text as the original literal
    string `"Foo<Bar>"`.
    
    
    **Note:** This class is similar to CharEscaper but with one very important difference.
    A CharEscaper can only process Java <a href="http://en.wikipedia.org/wiki/UTF-16">UTF16</a>
    characters in isolation and may not cope when it encounters surrogate pairs. This class
    facilitates the correct escaping of all Unicode characters.
    
    
    As there are important reasons, including potential security issues, to handle Unicode correctly
    if you are considering implementing a new escaper you should favor using UnicodeEscaper wherever
    possible.
    
    
    A `UnicodeEscaper` instance is required to be stateless, and safe when used concurrently by
    multiple threads.
    
    
    Several popular escapers are defined as constants in the class CharEscapers. To create
    your own escapers extend this class and implement the .escape(int) method.
    """

    def escape(self, string: str) -> str:
        """
        Returns the escaped form of a given literal string.
        
        
        If you are escaping input in arbitrary successive chunks, then it is not generally safe to use
        this method. If an input string ends with an unmatched high surrogate character, then this
        method will throw IllegalArgumentException. You should either ensure your input is
        valid <a href="http://en.wikipedia.org/wiki/UTF-16">UTF-16</a> before calling this method or
        use an escaped Appendable (as returned by .escape(Appendable)) which can cope
        with arbitrarily split input.
        
        
        **Note:** When implementing an escaper it is a good idea to override this method for
        efficiency by inlining the implementation of .nextEscapeIndex(CharSequence, int, int)
        directly. Doing this for PercentEscaper more than doubled the performance for unescaped
        strings (as measured by CharEscapersBenchmark).

        Arguments
        - string: the literal string to be escaped

        Returns
        - the escaped form of `string`

        Raises
        - NullPointerException: if `string` is null
        - IllegalArgumentException: if invalid surrogate characters are encountered
        """
        ...


    def escape(self, out: "Appendable") -> "Appendable":
        """
        Returns an `Appendable` instance which automatically escapes all text appended to it
        before passing the resulting text to an underlying `Appendable`.
        
        
        Unlike .escape(String) it is permitted to append arbitrarily split input to this
        Appendable, including input that is split over a surrogate pair. In this case the pending high
        surrogate character will not be processed until the corresponding low surrogate is appended.
        This means that a trailing high surrogate character at the end of the input cannot be detected
        and will be silently ignored. This is unavoidable since the Appendable interface has no
        `close()` method, and it is impossible to determine when the last characters have been
        appended.
        
        
        The methods of the returned object will propagate any exceptions thrown by the underlying
        `Appendable`.
        
        
        For well formed <a href="http://en.wikipedia.org/wiki/UTF-16">UTF-16</a> the escaping behavior
        is identical to that of .escape(String) and the following code is equivalent to (but
        much slower than) `escaper.escape(string)`:
        
        ```
        {
          &#064;code
          StringBuilder sb = new StringBuilder();
          escaper.escape(sb).append(string);
          return sb.toString();
        }
        ```

        Arguments
        - out: the underlying `Appendable` to append escaped output to

        Returns
        - an `Appendable` which passes text to `out` after escaping it

        Raises
        - NullPointerException: if `out` is null
        - IllegalArgumentException: if invalid surrogate characters are encountered
        """
        ...



"""
Python module generated from Java source file org.joml.PolygonsIntersection

Java source file obtained from artifact joml version 1.10.8

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import BitSet
from java.util import Collections
from java.util import Comparator
from org.joml import *
from typing import Any, Callable, Iterable, Tuple


class PolygonsIntersection:
    """
    Class for polygon/point intersection tests when testing many points against one or many static concave or convex, simple polygons.
    
    This is an implementation of the algorithm described in <a href="http://alienryderflex.com/polygon/">http://alienryderflex.com</a> and augmented with using a
    custom interval tree to avoid testing all polygon edges against a point, but only those that intersect the imaginary ray along the same y co-ordinate of the
    search point. This algorithm additionally also supports multiple polygons.
    
    This class is thread-safe and can be used in a multithreaded environment when testing many points against the same polygon concurrently.
    
    Reference: <a href="http://alienryderflex.com/polygon/">http://alienryderflex.com</a>

    Author(s)
    - Kai Burjack
    """

    def __init__(self, verticesXY: list[float], polygons: list[int], count: int):
        """
        Create a new PolygonsIntersection object with the given polygon vertices.
        
        The `verticesXY` array contains the x and y coordinates of all vertices. This array will not be copied so its content must remain constant for
        as long as the PolygonPointIntersection is used with it.

        Arguments
        - verticesXY: contains the x and y coordinates of all vertices
        - polygons: defines the start vertices of a new polygon. The first vertex of the first polygon is always the
                   vertex with index 0. In order to define a hole simply define a polygon that is completely inside another polygon
        - count: the number of vertices to use from the `verticesXY` array, staring with index 0
        """
        ...


    def testPoint(self, x: float, y: float) -> bool:
        """
        Test whether the given point `(x, y)` lies inside any polygon stored in this PolygonsIntersection object.
        
        This method is thread-safe and can be used to test many points concurrently.
        
        In order to obtain the index of the polygon the point is inside of, use .testPoint(float, float, BitSet)

        Arguments
        - x: the x coordinate of the point to test
        - y: the y coordinate of the point to test

        Returns
        - `True` iff the point lies inside any polygon; `False` otherwise

        See
        - .testPoint(float, float, BitSet)
        """
        ...


    def testPoint(self, x: float, y: float, inPolys: "BitSet") -> bool:
        """
        Test whether the given point `(x, y)` lies inside any polygon stored in this PolygonsIntersection object.
        
        This method is thread-safe and can be used to test many points concurrently.

        Arguments
        - x: the x coordinate of the point to test
        - y: the y coordinate of the point to test
        - inPolys: if not `null` then the *i*-th bit is set if the given point is inside the *i*-th polygon

        Returns
        - `True` iff the point lies inside the polygon and not inside a hole; `False` otherwise
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.UncaughtExceptionHandlers

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.util.concurrent import *
from java.util import Locale
from typing import Any, Callable, Iterable, Tuple


class UncaughtExceptionHandlers:
    """
    Factories for UncaughtExceptionHandler instances.

    Author(s)
    - Gregory Kick

    Since
    - 8.0
    """

    @staticmethod
    def systemExit() -> "UncaughtExceptionHandler":
        """
        Returns an exception handler that exits the system. This is particularly useful for the main
        thread, which may start up other, non-daemon threads, but fail to fully initialize the
        application successfully.
        
        Example usage:
        
        ```
        public static void main(String[] args) {
          Thread.currentThread().setUncaughtExceptionHandler(UncaughtExceptionHandlers.systemExit());
          ...
        ```
        
        The returned handler logs any exception at severity `SEVERE` and then shuts down the
        process with an exit status of 1, indicating abnormal termination.
        """
        ...



"""
Python module generated from Java source file com.google.common.escape.ParametricNullness

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.escape import *
from typing import Any, Callable, Iterable, Tuple


class ParametricNullness:
    """
    Annotates a "top-level" type-variable usage that takes its nullness from the type argument
    supplied by the user of the class. For example, `Multiset.Entry.getElement()` returns
    `@ParametricNullness E`, which means:
    
    
      - `getElement` on a `Multiset.Entry<@NonNull String>` returns `@NonNull
          String`.
      - `getElement` on a `Multiset.Entry<@Nullable String>` returns `@Nullable
          String`.
    
    
    This is the same behavior as type-variable usages have to Kotlin and to the Checker Framework.
    Contrast the method above to:
    
    
      - methods whose return type is a type variable but which can never return `null`,
          typically because the type forbids nullable type arguments: For example, `ImmutableList.get` returns `E`, but that value is never `null`. (Accordingly,
          `ImmutableList` is declared to forbid `ImmutableList<@Nullable String>`.)
      - methods whose return type is a type variable but which can return `null` regardless
          of the type argument supplied by the user of the class: For example, `ImmutableMap.get` returns `@Nullable E` because the method can return `null`
          even on an `ImmutableMap<K, @NonNull String>`.
    
    
    Consumers of this annotation include:
    
    
      - Kotlin, for which it makes the type-variable usage (a) a Kotlin platform type when the type
          argument is non-nullable and (b) nullable when the type argument is nullable. We use this
          to "undo" ElementTypesAreNonnullByDefault. It is the best we can do for Kotlin
          under our current constraints.
      - NullAway, which will <a
          href="https://github.com/google/guava/issues/6126#issuecomment-1204399671">treat it
          identically to `Nullable` as of version 0.9.9</a>. To treat it that way before then,
          you can set `-XepOpt:NullAway:CustomNullableAnnotations=com.google.common.base.ParametricNullness,...,com.google.common.util.concurrent.ParametricNullness`,
          where the `...` contains the names of all the other `ParametricNullness`
          annotations in Guava. Or you might prefer to omit Guava from your `AnnotatedPackages`
          list.
      - <a href="https://developers.google.com/j2objc">J2ObjC</a>
      - `NullPointerTester`, at least in the Android backport (where the type-use annotations
          `NullPointerTester` would need are not available) and in case of <a
          href="https://bugs.openjdk.java.net/browse/JDK-8202469">JDK-8202469</a>
    
    
    This annotation is a temporary hack. We will remove it after we're able to adopt the <a
    href="https://jspecify.dev/">JSpecify</a> nullness annotations and <a
    href="https://github.com/google/guava/issues/6126#issuecomment-1203145963">tools no longer need
    it</a>.
    """





"""
Python module generated from Java source file org.bukkit.block.Beacon

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Nameable
from org.bukkit.block import *
from org.bukkit.entity import LivingEntity
from org.bukkit.potion import PotionEffect
from org.bukkit.potion import PotionEffectType
from typing import Any, Callable, Iterable, Tuple


class Beacon(TileState, Lockable, Nameable):
    """
    Represents a captured state of a beacon.
    """

    def getEntitiesInRange(self) -> Iterable["LivingEntity"]:
        """
        Returns the list of players within the beacon's range of effect.
        
        This will return an empty list if the block represented by this state is
        no longer a beacon.

        Returns
        - the players in range

        Raises
        - IllegalStateException: if this block state is not placed
        """
        ...


    def getTier(self) -> int:
        """
        Returns the tier of the beacon pyramid (0-4). The tier refers to the
        beacon's power level, based on how many layers of blocks are in the
        pyramid. Tier 1 refers to a beacon with one layer of 9 blocks under it.

        Returns
        - the beacon tier
        """
        ...


    def getPrimaryEffect(self) -> "PotionEffect":
        """
        Returns the primary effect set on the beacon

        Returns
        - the primary effect or null if not set
        """
        ...


    def setPrimaryEffect(self, effect: "PotionEffectType") -> None:
        """
        Set the primary effect on this beacon, or null to clear.

        Arguments
        - effect: new primary effect
        """
        ...


    def getSecondaryEffect(self) -> "PotionEffect":
        """
        Returns the secondary effect set on the beacon.

        Returns
        - the secondary effect or null if no secondary effect
        """
        ...


    def setSecondaryEffect(self, effect: "PotionEffectType") -> None:
        """
        Set the secondary effect on this beacon, or null to clear. Note that tier
        must be &gt;= 4 for this effect to be active.

        Arguments
        - effect: desired secondary effect
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.EntityPotionEffectEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import LivingEntity
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from org.bukkit.potion import PotionEffect
from org.bukkit.potion import PotionEffectType
from typing import Any, Callable, Iterable, Tuple


class EntityPotionEffectEvent(EntityEvent, Cancellable):
    """
    Called when a potion effect is modified on an entity.
    
    If the event is cancelled, no change will be made on the entity.
    """

    def __init__(self, livingEntity: "LivingEntity", oldEffect: "PotionEffect", newEffect: "PotionEffect", cause: "Cause", action: "Action", override: bool):
        ...


    def getOldEffect(self) -> "PotionEffect":
        """
        Gets the old potion effect of the changed type, which will be removed.

        Returns
        - The old potion effect or null if the entity did not have the
        changed effect type.
        """
        ...


    def getNewEffect(self) -> "PotionEffect":
        """
        Gets new potion effect of the changed type to be applied.

        Returns
        - The new potion effect or null if the effect of the changed type
        will be removed.
        """
        ...


    def getCause(self) -> "Cause":
        """
        Gets the cause why the effect has changed.

        Returns
        - A Cause value why the effect has changed.
        """
        ...


    def getAction(self) -> "Action":
        """
        Gets the action which will be performed on the potion effect type.

        Returns
        - An action to be performed on the potion effect type.
        """
        ...


    def getModifiedType(self) -> "PotionEffectType":
        """
        Gets the modified potion effect type.

        Returns
        - The effect type which will be modified on the entity.
        """
        ...


    def isOverride(self) -> bool:
        """
        Returns if the new potion effect will override the old potion effect
        (Only applicable for the CHANGED Action).

        Returns
        - If the new effect will override the old one.
        """
        ...


    def setOverride(self, override: bool) -> None:
        """
        Sets if the new potion effect will override the old potion effect (Only
        applicable for the CHANGED action).

        Arguments
        - override: If the new effect will override the old one.
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class Action(Enum):
        """
        An enum to specify the action to be performed.
        """

        ADDED = 0
        """
        When the potion effect is added because the entity didn't have it's
        type.
        """
        CHANGED = 1
        """
        When the entity already had the potion effect type, but the effect is
        changed.
        """
        CLEARED = 2
        """
        When the effect is removed due to all effects being removed.
        """
        REMOVED = 3
        """
        When the potion effect type is completely removed.
        """


    class Cause(Enum):
        """
        An enum to specify the cause why an effect was changed.
        """

        AREA_EFFECT_CLOUD = 0
        """
        When the entity stands inside an area effect cloud.
        """
        ARROW = 1
        """
        When the entity is hit by an spectral or tipped arrow.
        """
        ATTACK = 2
        """
        When the entity is inflicted with a potion effect due to an entity
        attack (e.g. a cave spider or a shulker bullet).
        """
        AXOLOTL = 3
        """
        When an entity gets the effect from an axolotl.
        """
        BEACON = 4
        """
        When beacon effects get applied due to the entity being nearby.
        """
        COMMAND = 5
        """
        When a potion effect is changed due to the /effect command.
        """
        CONDUIT = 6
        """
        When the entity gets the effect from a conduit.
        """
        CONVERSION = 7
        """
        When a conversion from a villager zombie to a villager is started or
        finished.
        """
        DEATH = 8
        """
        When all effects are removed due to death.
        """
        DOLPHIN = 9
        """
        When the entity gets the effect from a dolphin.
        """
        EXPIRATION = 10
        """
        When the effect was removed due to expiration.
        """
        FOOD = 11
        """
        When an effect is inflicted due to food (e.g. when a player eats or a
        cookie is given to a parrot).
        """
        ILLUSION = 12
        """
        When an illusion illager makes himself disappear.
        """
        MILK = 13
        """
        When all effects are removed due to a bucket of milk.
        """
        PATROL_CAPTAIN = 14
        """
        When a player gets bad omen after killing a patrol captain.
        """
        PLUGIN = 15
        """
        When a potion effect is modified through the plugin methods.
        """
        POTION_DRINK = 16
        """
        When the entity drinks a potion.
        """
        POTION_SPLASH = 17
        """
        When the entity is inflicted with an effect due to a splash potion.
        """
        SPIDER_SPAWN = 18
        """
        When a spider gets effects when spawning on hard difficulty.
        """
        TOTEM = 19
        """
        When the entity gets effects from a totem item saving it's life.
        """
        TURTLE_HELMET = 20
        """
        When the entity gets water breathing by wearing a turtle helmet.
        """
        UNKNOWN = 21
        """
        When the Cause is missing.
        """
        VILLAGER_TRADE = 22
        """
        When a villager gets regeneration after a trade.
        """
        WARDEN = 23
        """
        When an entity gets the effect from a warden.
        """
        WITHER_ROSE = 24
        """
        When an entity comes in contact with a wither rose.
        """



"""
Python module generated from Java source file org.bukkit.configuration.serialization.SerializableAs

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.configuration.serialization import *
from typing import Any, Callable, Iterable, Tuple


class SerializableAs:
    """
    Represents an "alias" that a ConfigurationSerializable may be
    stored as.
    If this is not present on a ConfigurationSerializable class, it
    will use the fully qualified name of the class.
    
    This value will be stored in the configuration so that the configuration
    deserialization can determine what type it is.
    
    Using this annotation on any other class than a ConfigurationSerializable will have no effect.

    See
    - ConfigurationSerialization.registerClass(Class, String)
    """

    def value(self) -> str:
        """
        This is the name your class will be stored and retrieved as.
        
        This name MUST be unique. We recommend using names such as
        "MyPluginThing" instead of "Thing".

        Returns
        - Name to serialize the class as.
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.tokens.AliasToken

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.tokens import *
from typing import Any, Callable, Iterable, Tuple


class AliasToken(Token):
    """
    Alias
    """

    def __init__(self, value: str, startMark: "Mark", endMark: "Mark"):
        """
        Alias

        Arguments
        - value: - alias
        - startMark: - start
        - endMark: - end
        """
        ...


    def getValue(self) -> str:
        """
        getter

        Returns
        - alias
        """
        ...


    def getTokenId(self) -> "Token.ID":
        ...



"""
Python module generated from Java source file java.math.RoundingMode

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from java.math import *
from typing import Any, Callable, Iterable, Tuple


class RoundingMode(Enum):
    """
    Specifies a *rounding policy* for numerical operations capable
    of discarding precision. Each rounding mode indicates how the least
    significant returned digit of a rounded result is to be calculated.
    If fewer digits are returned than the digits needed to represent
    the exact numerical result, the discarded digits will be referred
    to as the *discarded fraction* regardless the digits'
    contribution to the value of the number.  In other words,
    considered as a numerical value, the discarded fraction could have
    an absolute value greater than one.
    
    Each rounding mode description includes a table listing how
    different two-digit decimal values would round to a one digit
    decimal value under the rounding mode in question.  The result
    column in the tables could be gotten by creating a
    `BigDecimal` number with the specified value, forming a
    MathContext object with the proper settings
    (`precision` set to `1`, and the
    `roundingMode` set to the rounding mode in question), and
    calling BigDecimal.round round on this number with the
    proper `MathContext`.  A summary table showing the results
    of these rounding operations for all rounding modes appears below.
    
    <table class="striped">
    <caption>**Summary of Rounding Operations Under Different Rounding Modes**</caption>
    <thead>
    <tr><th scope="col" rowspan="2">Input Number</th><th scope="col"colspan=8>Result of rounding input to one digit with the given
                              rounding mode</th>
    <tr style="vertical-align:top">
                                  <th>`UP`</th>
                                              <th>`DOWN`</th>
                                                           <th>`CEILING`</th>
                                                                          <th>`FLOOR`</th>
                                                                                       <th>`HALF_UP`</th>
                                                                                                      <th>`HALF_DOWN`</th>
                                                                                                                       <th>`HALF_EVEN`</th>
                                                                                                                                        <th>`UNNECESSARY`</th>
    </thead>
    <tbody style="text-align:right">
    
    <tr><th scope="row">5.5</th>  <td>6</td>  <td>5</td>    <td>6</td>    <td>5</td>  <td>6</td>      <td>5</td>       <td>6</td>       <td>throw `ArithmeticException`</td>
    <tr><th scope="row">2.5</th>  <td>3</td>  <td>2</td>    <td>3</td>    <td>2</td>  <td>3</td>      <td>2</td>       <td>2</td>       <td>throw `ArithmeticException`</td>
    <tr><th scope="row">1.6</th>  <td>2</td>  <td>1</td>    <td>2</td>    <td>1</td>  <td>2</td>      <td>2</td>       <td>2</td>       <td>throw `ArithmeticException`</td>
    <tr><th scope="row">1.1</th>  <td>2</td>  <td>1</td>    <td>2</td>    <td>1</td>  <td>1</td>      <td>1</td>       <td>1</td>       <td>throw `ArithmeticException`</td>
    <tr><th scope="row">1.0</th>  <td>1</td>  <td>1</td>    <td>1</td>    <td>1</td>  <td>1</td>      <td>1</td>       <td>1</td>       <td>1</td>
    <tr><th scope="row">-1.0</th> <td>-1</td> <td>-1</td>   <td>-1</td>   <td>-1</td> <td>-1</td>     <td>-1</td>      <td>-1</td>      <td>-1</td>
    <tr><th scope="row">-1.1</th> <td>-2</td> <td>-1</td>   <td>-1</td>   <td>-2</td> <td>-1</td>     <td>-1</td>      <td>-1</td>      <td>throw `ArithmeticException`</td>
    <tr><th scope="row">-1.6</th> <td>-2</td> <td>-1</td>   <td>-1</td>   <td>-2</td> <td>-2</td>     <td>-2</td>      <td>-2</td>      <td>throw `ArithmeticException`</td>
    <tr><th scope="row">-2.5</th> <td>-3</td> <td>-2</td>   <td>-2</td>   <td>-3</td> <td>-3</td>     <td>-2</td>      <td>-2</td>      <td>throw `ArithmeticException`</td>
    <tr><th scope="row">-5.5</th> <td>-6</td> <td>-5</td>   <td>-5</td>   <td>-6</td> <td>-6</td>     <td>-5</td>      <td>-6</td>      <td>throw `ArithmeticException`</td>
    </tbody>
    </table>
    
    
    This `enum` is intended to replace the integer-based
    enumeration of rounding mode constants in BigDecimal
    (BigDecimal.ROUND_UP, BigDecimal.ROUND_DOWN,
    etc. ).

    Author(s)
    - Joseph D. Darcy

    See
    - MathContext

    Since
    - 1.5

    Unknown Tags
    - Five of the rounding modes declared in this class correspond to
    rounding-direction attributes defined in the <cite>IEEE Standard
    for Floating-Point Arithmetic</cite>, IEEE 754-2019. Where present,
    this correspondence will be noted in the documentation of the
    particular constant.
    """

    UP = (BigDecimal.ROUND_UP)
    """
    Rounding mode to round away from zero.  Always increments the
    digit prior to a non-zero discarded fraction.  Note that this
    rounding mode never decreases the magnitude of the calculated
    value.
    
    Example:
    <table class="striped">
    <caption>Rounding mode UP Examples</caption>
    <thead>
    <tr style="vertical-align:top"><th scope="col">Input Number</th>
       <th scope="col">Input rounded to one digit with `UP` rounding
    </thead>
    <tbody style="text-align:right">
    <tr><th scope="row">5.5</th>  <td>6</td>
    <tr><th scope="row">2.5</th>  <td>3</td>
    <tr><th scope="row">1.6</th>  <td>2</td>
    <tr><th scope="row">1.1</th>  <td>2</td>
    <tr><th scope="row">1.0</th>  <td>1</td>
    <tr><th scope="row">-1.0</th> <td>-1</td>
    <tr><th scope="row">-1.1</th> <td>-2</td>
    <tr><th scope="row">-1.6</th> <td>-2</td>
    <tr><th scope="row">-2.5</th> <td>-3</td>
    <tr><th scope="row">-5.5</th> <td>-6</td>
    </tbody>
    </table>
    """
    DOWN = (BigDecimal.ROUND_DOWN)
    """
    Rounding mode to round towards zero.  Never increments the digit
    prior to a discarded fraction (i.e., truncates).  Note that this
    rounding mode never increases the magnitude of the calculated value.
    This mode corresponds to the IEEE 754-2019 rounding-direction
    attribute roundTowardZero.
    
    Example:
    <table class="striped">
    <caption>Rounding mode DOWN Examples</caption>
    <thead>
    <tr style="vertical-align:top"><th scope="col">Input Number</th>
       <th scope="col">Input rounded to one digit with `DOWN` rounding
    </thead>
    <tbody style="text-align:right">
    <tr><th scope="row">5.5</th>  <td>5</td>
    <tr><th scope="row">2.5</th>  <td>2</td>
    <tr><th scope="row">1.6</th>  <td>1</td>
    <tr><th scope="row">1.1</th>  <td>1</td>
    <tr><th scope="row">1.0</th>  <td>1</td>
    <tr><th scope="row">-1.0</th> <td>-1</td>
    <tr><th scope="row">-1.1</th> <td>-1</td>
    <tr><th scope="row">-1.6</th> <td>-1</td>
    <tr><th scope="row">-2.5</th> <td>-2</td>
    <tr><th scope="row">-5.5</th> <td>-5</td>
    </tbody>
    </table>
    """
    CEILING = (BigDecimal.ROUND_CEILING)
    """
    Rounding mode to round towards positive infinity.  If the
    result is positive, behaves as for `RoundingMode.UP`;
    if negative, behaves as for `RoundingMode.DOWN`.  Note
    that this rounding mode never decreases the calculated value.
    This mode corresponds to the IEEE 754-2019 rounding-direction
    attribute roundTowardPositive.
    
    Example:
    <table class="striped">
    <caption>Rounding mode CEILING Examples</caption>
    <thead>
    <tr style="vertical-align:top"><th>Input Number</th>
       <th>Input rounded to one digit with `CEILING` rounding
    </thead>
    <tbody style="text-align:right">
    <tr><th scope="row">5.5</th>  <td>6</td>
    <tr><th scope="row">2.5</th>  <td>3</td>
    <tr><th scope="row">1.6</th>  <td>2</td>
    <tr><th scope="row">1.1</th>  <td>2</td>
    <tr><th scope="row">1.0</th>  <td>1</td>
    <tr><th scope="row">-1.0</th> <td>-1</td>
    <tr><th scope="row">-1.1</th> <td>-1</td>
    <tr><th scope="row">-1.6</th> <td>-1</td>
    <tr><th scope="row">-2.5</th> <td>-2</td>
    <tr><th scope="row">-5.5</th> <td>-5</td>
    </tbody>
    </table>
    """
    FLOOR = (BigDecimal.ROUND_FLOOR)
    """
    Rounding mode to round towards negative infinity.  If the
    result is positive, behave as for `RoundingMode.DOWN`;
    if negative, behave as for `RoundingMode.UP`.  Note that
    this rounding mode never increases the calculated value.
    This mode corresponds to the IEEE 754-2019 rounding-direction
    attribute roundTowardNegative.
    
    Example:
    <table class="striped">
    <caption>Rounding mode FLOOR Examples</caption>
    <thead>
    <tr style="vertical-align:top"><th scope="col">Input Number</th>
       <th scope="col">Input rounded to one digit with `FLOOR` rounding
    </thead>
    <tbody style="text-align:right">
    <tr><th scope="row">5.5</th>  <td>5</td>
    <tr><th scope="row">2.5</th>  <td>2</td>
    <tr><th scope="row">1.6</th>  <td>1</td>
    <tr><th scope="row">1.1</th>  <td>1</td>
    <tr><th scope="row">1.0</th>  <td>1</td>
    <tr><th scope="row">-1.0</th> <td>-1</td>
    <tr><th scope="row">-1.1</th> <td>-2</td>
    <tr><th scope="row">-1.6</th> <td>-2</td>
    <tr><th scope="row">-2.5</th> <td>-3</td>
    <tr><th scope="row">-5.5</th> <td>-6</td>
    </tbody>
    </table>
    """
    HALF_UP = (BigDecimal.ROUND_HALF_UP)
    """
    Rounding mode to round towards "nearest neighbor"
    unless both neighbors are equidistant, in which case round up.
    Behaves as for `RoundingMode.UP` if the discarded
    fraction is &ge; 0.5; otherwise, behaves as for
    `RoundingMode.DOWN`.  Note that this is the rounding
    mode commonly taught at school.
    This mode corresponds to the IEEE 754-2019 rounding-direction
    attribute roundTiesToAway.
    
    Example:
    <table class="striped">
    <caption>Rounding mode HALF_UP Examples</caption>
    <thead>
    <tr style="vertical-align:top"><th scope="col">Input Number</th>
       <th scope="col">Input rounded to one digit with `HALF_UP` rounding
    </thead>
    <tbody style="text-align:right">
    <tr><th scope="row">5.5</th>  <td>6</td>
    <tr><th scope="row">2.5</th>  <td>3</td>
    <tr><th scope="row">1.6</th>  <td>2</td>
    <tr><th scope="row">1.1</th>  <td>1</td>
    <tr><th scope="row">1.0</th>  <td>1</td>
    <tr><th scope="row">-1.0</th> <td>-1</td>
    <tr><th scope="row">-1.1</th> <td>-1</td>
    <tr><th scope="row">-1.6</th> <td>-2</td>
    <tr><th scope="row">-2.5</th> <td>-3</td>
    <tr><th scope="row">-5.5</th> <td>-6</td>
    </tbody>
    </table>
    """
    HALF_DOWN = (BigDecimal.ROUND_HALF_DOWN)
    """
    Rounding mode to round towards "nearest neighbor"
    unless both neighbors are equidistant, in which case round
    down.  Behaves as for `RoundingMode.UP` if the discarded
    fraction is &gt; 0.5; otherwise, behaves as for
    `RoundingMode.DOWN`.
    
    Example:
    <table class="striped">
    <caption>Rounding mode HALF_DOWN Examples</caption>
    <thead>
    <tr style="vertical-align:top"><th scope="col">Input Number</th>
       <th scope="col">Input rounded to one digit with `HALF_DOWN` rounding
    </thead>
    <tbody style="text-align:right">
    <tr><th scope="row">5.5</th>  <td>5</td>
    <tr><th scope="row">2.5</th>  <td>2</td>
    <tr><th scope="row">1.6</th>  <td>2</td>
    <tr><th scope="row">1.1</th>  <td>1</td>
    <tr><th scope="row">1.0</th>  <td>1</td>
    <tr><th scope="row">-1.0</th> <td>-1</td>
    <tr><th scope="row">-1.1</th> <td>-1</td>
    <tr><th scope="row">-1.6</th> <td>-2</td>
    <tr><th scope="row">-2.5</th> <td>-2</td>
    <tr><th scope="row">-5.5</th> <td>-5</td>
    </tbody>
    </table>
    """
    HALF_EVEN = (BigDecimal.ROUND_HALF_EVEN)
    """
    Rounding mode to round towards the "nearest neighbor"
    unless both neighbors are equidistant, in which case, round
    towards the even neighbor.  Behaves as for
    `RoundingMode.HALF_UP` if the digit to the left of the
    discarded fraction is odd; behaves as for
    `RoundingMode.HALF_DOWN` if it's even.  Note that this
    is the rounding mode that statistically minimizes cumulative
    error when applied repeatedly over a sequence of calculations.
    It is sometimes known as "Banker's rounding," and is
    chiefly used in the USA.  This rounding mode is analogous to
    the rounding policy used for `float` and `double`
    arithmetic in Java.
    This mode corresponds to the IEEE 754-2019 rounding-direction
    attribute roundTiesToEven.
    
    Example:
    <table class="striped">
    <caption>Rounding mode HALF_EVEN Examples</caption>
    <thead>
    <tr style="vertical-align:top"><th scope="col">Input Number</th>
       <th scope="col">Input rounded to one digit with `HALF_EVEN` rounding
    </thead>
    <tbody style="text-align:right">
    <tr><th scope="row">5.5</th>  <td>6</td>
    <tr><th scope="row">2.5</th>  <td>2</td>
    <tr><th scope="row">1.6</th>  <td>2</td>
    <tr><th scope="row">1.1</th>  <td>1</td>
    <tr><th scope="row">1.0</th>  <td>1</td>
    <tr><th scope="row">-1.0</th> <td>-1</td>
    <tr><th scope="row">-1.1</th> <td>-1</td>
    <tr><th scope="row">-1.6</th> <td>-2</td>
    <tr><th scope="row">-2.5</th> <td>-2</td>
    <tr><th scope="row">-5.5</th> <td>-6</td>
    </tbody>
    </table>
    """
    UNNECESSARY = (BigDecimal.ROUND_UNNECESSARY)
    """
    Rounding mode to assert that the requested operation has an exact
    result, hence no rounding is necessary.  If this rounding mode is
    specified on an operation that yields an inexact result, an
    `ArithmeticException` is thrown.
    Example:
    <table class="striped">
    <caption>Rounding mode UNNECESSARY Examples</caption>
    <thead>
    <tr style="vertical-align:top"><th scope="col">Input Number</th>
       <th scope="col">Input rounded to one digit with `UNNECESSARY` rounding
    </thead>
    <tbody style="text-align:right">
    <tr><th scope="row">5.5</th>  <td>throw `ArithmeticException`</td>
    <tr><th scope="row">2.5</th>  <td>throw `ArithmeticException`</td>
    <tr><th scope="row">1.6</th>  <td>throw `ArithmeticException`</td>
    <tr><th scope="row">1.1</th>  <td>throw `ArithmeticException`</td>
    <tr><th scope="row">1.0</th>  <td>1</td>
    <tr><th scope="row">-1.0</th> <td>-1</td>
    <tr><th scope="row">-1.1</th> <td>throw `ArithmeticException`</td>
    <tr><th scope="row">-1.6</th> <td>throw `ArithmeticException`</td>
    <tr><th scope="row">-2.5</th> <td>throw `ArithmeticException`</td>
    <tr><th scope="row">-5.5</th> <td>throw `ArithmeticException`</td>
    </tbody>
    </table>
    """


    @staticmethod
    def valueOf(rm: int) -> "RoundingMode":
        """
        Returns the `RoundingMode` object corresponding to a
        legacy integer rounding mode constant in BigDecimal.

        Arguments
        - rm: legacy integer rounding mode to convert

        Returns
        - `RoundingMode` corresponding to the given integer.

        Raises
        - IllegalArgumentException: integer is out of range
        """
        ...



"""
Python module generated from Java source file java.io.PrintWriter

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from java.nio.charset import Charset
from java.nio.charset import IllegalCharsetNameException
from java.nio.charset import UnsupportedCharsetException
from java.util import Formatter
from java.util import Locale
from java.util import Objects
from typing import Any, Callable, Iterable, Tuple


class PrintWriter(Writer):

    def __init__(self, out: "Writer"):
        """
        Creates a new PrintWriter, without automatic line flushing.

        Arguments
        - out: A character-output stream
        """
        ...


    def __init__(self, out: "Writer", autoFlush: bool):
        """
        Creates a new PrintWriter.

        Arguments
        - out: A character-output stream
        - autoFlush: A boolean; if True, the `println`,
                           `printf`, or `format` methods will
                           flush the output buffer
        """
        ...


    def __init__(self, out: "OutputStream"):
        """
        Creates a new PrintWriter, without automatic line flushing, from an
        existing OutputStream.  This convenience constructor creates the
        necessary intermediate OutputStreamWriter, which will convert characters
        into bytes using the default character encoding.

        Arguments
        - out: An output stream

        See
        - java.io.OutputStreamWriter.OutputStreamWriter(java.io.OutputStream)
        """
        ...


    def __init__(self, out: "OutputStream", autoFlush: bool):
        """
        Creates a new PrintWriter from an existing OutputStream.  This
        convenience constructor creates the necessary intermediate
        OutputStreamWriter, which will convert characters into bytes using the
        default character encoding.

        Arguments
        - out: An output stream
        - autoFlush: A boolean; if True, the `println`,
                           `printf`, or `format` methods will
                           flush the output buffer

        See
        - java.io.OutputStreamWriter.OutputStreamWriter(java.io.OutputStream)
        """
        ...


    def __init__(self, out: "OutputStream", autoFlush: bool, charset: "Charset"):
        """
        Creates a new PrintWriter from an existing OutputStream.  This
        convenience constructor creates the necessary intermediate
        OutputStreamWriter, which will convert characters into bytes using the
        specified charset.

        Arguments
        - out: An output stream
        - autoFlush: A boolean; if True, the `println`,
                           `printf`, or `format` methods will
                           flush the output buffer
        - charset: A java.nio.charset.Charset charset

        Since
        - 10
        """
        ...


    def __init__(self, fileName: str):
        """
        Creates a new PrintWriter, without automatic line flushing, with the
        specified file name.  This convenience constructor creates the necessary
        intermediate java.io.OutputStreamWriter OutputStreamWriter,
        which will encode characters using the java.nio.charset.Charset.defaultCharset() default charset for this
        instance of the Java virtual machine.

        Arguments
        - fileName: The name of the file to use as the destination of this writer.
                If the file exists then it will be truncated to zero size;
                otherwise, a new file will be created.  The output will be
                written to the file and is buffered.

        Raises
        - FileNotFoundException: If the given string does not denote an existing, writable
                 regular file and a new regular file of that name cannot be
                 created, or if some other error occurs while opening or
                 creating the file
        - SecurityException: If a security manager is present and SecurityManager.checkWrite checkWrite(fileName) denies write
                 access to the file

        Since
        - 1.5
        """
        ...


    def __init__(self, fileName: str, csn: str):
        """
        Creates a new PrintWriter, without automatic line flushing, with the
        specified file name and charset.  This convenience constructor creates
        the necessary intermediate java.io.OutputStreamWriter
        OutputStreamWriter, which will encode characters using the provided
        charset.

        Arguments
        - fileName: The name of the file to use as the destination of this writer.
                If the file exists then it will be truncated to zero size;
                otherwise, a new file will be created.  The output will be
                written to the file and is buffered.
        - csn: The name of a supported java.nio.charset.Charset
                charset

        Raises
        - FileNotFoundException: If the given string does not denote an existing, writable
                 regular file and a new regular file of that name cannot be
                 created, or if some other error occurs while opening or
                 creating the file
        - SecurityException: If a security manager is present and SecurityManager.checkWrite checkWrite(fileName) denies write
                 access to the file
        - UnsupportedEncodingException: If the named charset is not supported

        Since
        - 1.5
        """
        ...


    def __init__(self, fileName: str, charset: "Charset"):
        """
        Creates a new PrintWriter, without automatic line flushing, with the
        specified file name and charset.  This convenience constructor creates
        the necessary intermediate java.io.OutputStreamWriter
        OutputStreamWriter, which will encode characters using the provided
        charset.

        Arguments
        - fileName: The name of the file to use as the destination of this writer.
                If the file exists then it will be truncated to zero size;
                otherwise, a new file will be created.  The output will be
                written to the file and is buffered.
        - charset: A java.nio.charset.Charset charset

        Raises
        - IOException: if an I/O error occurs while opening or creating the file
        - SecurityException: If a security manager is present and SecurityManager.checkWrite checkWrite(fileName) denies write
                 access to the file

        Since
        - 10
        """
        ...


    def __init__(self, file: "File"):
        """
        Creates a new PrintWriter, without automatic line flushing, with the
        specified file.  This convenience constructor creates the necessary
        intermediate java.io.OutputStreamWriter OutputStreamWriter,
        which will encode characters using the java.nio.charset.Charset.defaultCharset() default charset for this
        instance of the Java virtual machine.

        Arguments
        - file: The file to use as the destination of this writer.  If the file
                exists then it will be truncated to zero size; otherwise, a new
                file will be created.  The output will be written to the file
                and is buffered.

        Raises
        - FileNotFoundException: If the given file object does not denote an existing, writable
                 regular file and a new regular file of that name cannot be
                 created, or if some other error occurs while opening or
                 creating the file
        - SecurityException: If a security manager is present and SecurityManager.checkWrite checkWrite(file.getPath())
                 denies write access to the file

        Since
        - 1.5
        """
        ...


    def __init__(self, file: "File", csn: str):
        """
        Creates a new PrintWriter, without automatic line flushing, with the
        specified file and charset.  This convenience constructor creates the
        necessary intermediate java.io.OutputStreamWriter
        OutputStreamWriter, which will encode characters using the provided
        charset.

        Arguments
        - file: The file to use as the destination of this writer.  If the file
                exists then it will be truncated to zero size; otherwise, a new
                file will be created.  The output will be written to the file
                and is buffered.
        - csn: The name of a supported java.nio.charset.Charset
                charset

        Raises
        - FileNotFoundException: If the given file object does not denote an existing, writable
                 regular file and a new regular file of that name cannot be
                 created, or if some other error occurs while opening or
                 creating the file
        - SecurityException: If a security manager is present and SecurityManager.checkWrite checkWrite(file.getPath())
                 denies write access to the file
        - UnsupportedEncodingException: If the named charset is not supported

        Since
        - 1.5
        """
        ...


    def __init__(self, file: "File", charset: "Charset"):
        """
        Creates a new PrintWriter, without automatic line flushing, with the
        specified file and charset.  This convenience constructor creates the
        necessary intermediate java.io.OutputStreamWriter
        OutputStreamWriter, which will encode characters using the provided
        charset.

        Arguments
        - file: The file to use as the destination of this writer.  If the file
                exists then it will be truncated to zero size; otherwise, a new
                file will be created.  The output will be written to the file
                and is buffered.
        - charset: A java.nio.charset.Charset charset

        Raises
        - IOException: if an I/O error occurs while opening or creating the file
        - SecurityException: If a security manager is present and SecurityManager.checkWrite checkWrite(file.getPath())
                 denies write access to the file

        Since
        - 10
        """
        ...


    def flush(self) -> None:
        """
        Flushes the stream.

        See
        - .checkError()
        """
        ...


    def close(self) -> None:
        """
        Closes the stream and releases any system resources associated
        with it. Closing a previously closed stream has no effect.

        See
        - .checkError()
        """
        ...


    def checkError(self) -> bool:
        """
        Flushes the stream if it's not closed and checks its error state.

        Returns
        - `True` if the print stream has encountered an error,
                 either on the underlying output stream or during a format
                 conversion.
        """
        ...


    def write(self, c: int) -> None:
        """
        Writes a single character.

        Arguments
        - c: int specifying a character to be written.
        """
        ...


    def write(self, buf: list[str], off: int, len: int) -> None:
        """
        Writes A Portion of an array of characters.

        Arguments
        - buf: Array of characters
        - off: Offset from which to start writing characters
        - len: Number of characters to write

        Raises
        - IndexOutOfBoundsException: If the values of the `off` and `len` parameters
                 cause the corresponding method of the underlying `Writer`
                 to throw an `IndexOutOfBoundsException`
        """
        ...


    def write(self, buf: list[str]) -> None:
        """
        Writes an array of characters.  This method cannot be inherited from the
        Writer class because it must suppress I/O exceptions.

        Arguments
        - buf: Array of characters to be written
        """
        ...


    def write(self, s: str, off: int, len: int) -> None:
        """
        Writes a portion of a string.

        Arguments
        - s: A String
        - off: Offset from which to start writing characters
        - len: Number of characters to write

        Raises
        - IndexOutOfBoundsException: If the values of the `off` and `len` parameters
                 cause the corresponding method of the underlying `Writer`
                 to throw an `IndexOutOfBoundsException`
        """
        ...


    def write(self, s: str) -> None:
        """
        Writes a string.  This method cannot be inherited from the Writer class
        because it must suppress I/O exceptions.

        Arguments
        - s: String to be written
        """
        ...


    def print(self, b: bool) -> None:
        """
        Prints a boolean value.  The string produced by java.lang.String.valueOf(boolean) is translated into bytes
        according to the platform's default character encoding, and these bytes
        are written in exactly the manner of the .write(int) method.

        Arguments
        - b: The `boolean` to be printed
        """
        ...


    def print(self, c: str) -> None:
        """
        Prints a character.  The character is translated into one or more bytes
        according to the platform's default character encoding, and these bytes
        are written in exactly the manner of the .write(int) method.

        Arguments
        - c: The `char` to be printed
        """
        ...


    def print(self, i: int) -> None:
        """
        Prints an integer.  The string produced by java.lang.String.valueOf(int) is translated into bytes according
        to the platform's default character encoding, and these bytes are
        written in exactly the manner of the .write(int)
        method.

        Arguments
        - i: The `int` to be printed

        See
        - java.lang.Integer.toString(int)
        """
        ...


    def print(self, l: int) -> None:
        """
        Prints a long integer.  The string produced by java.lang.String.valueOf(long) is translated into bytes
        according to the platform's default character encoding, and these bytes
        are written in exactly the manner of the .write(int)
        method.

        Arguments
        - l: The `long` to be printed

        See
        - java.lang.Long.toString(long)
        """
        ...


    def print(self, f: float) -> None:
        """
        Prints a floating-point number.  The string produced by java.lang.String.valueOf(float) is translated into bytes
        according to the platform's default character encoding, and these bytes
        are written in exactly the manner of the .write(int)
        method.

        Arguments
        - f: The `float` to be printed

        See
        - java.lang.Float.toString(float)
        """
        ...


    def print(self, d: float) -> None:
        """
        Prints a double-precision floating-point number.  The string produced by
        java.lang.String.valueOf(double) is translated into
        bytes according to the platform's default character encoding, and these
        bytes are written in exactly the manner of the .write(int) method.

        Arguments
        - d: The `double` to be printed

        See
        - java.lang.Double.toString(double)
        """
        ...


    def print(self, s: list[str]) -> None:
        """
        Prints an array of characters.  The characters are converted into bytes
        according to the platform's default character encoding, and these bytes
        are written in exactly the manner of the .write(int)
        method.

        Arguments
        - s: The array of chars to be printed

        Raises
        - NullPointerException: If `s` is `null`
        """
        ...


    def print(self, s: str) -> None:
        """
        Prints a string.  If the argument is `null` then the string
        `"null"` is printed.  Otherwise, the string's characters are
        converted into bytes according to the platform's default character
        encoding, and these bytes are written in exactly the manner of the
        .write(int) method.

        Arguments
        - s: The `String` to be printed
        """
        ...


    def print(self, obj: "Object") -> None:
        """
        Prints an object.  The string produced by the java.lang.String.valueOf(Object) method is translated into bytes
        according to the platform's default character encoding, and these bytes
        are written in exactly the manner of the .write(int)
        method.

        Arguments
        - obj: The `Object` to be printed

        See
        - java.lang.Object.toString()
        """
        ...


    def println(self) -> None:
        """
        Terminates the current line by writing the line separator string.  The
        line separator is System.lineSeparator() and is not necessarily
        a single newline character (`'\n'`).
        """
        ...


    def println(self, x: bool) -> None:
        """
        Prints a boolean value and then terminates the line.  This method behaves
        as though it invokes .print(boolean) and then
        .println().

        Arguments
        - x: the `boolean` value to be printed
        """
        ...


    def println(self, x: str) -> None:
        """
        Prints a character and then terminates the line.  This method behaves as
        though it invokes .print(char) and then .println().

        Arguments
        - x: the `char` value to be printed
        """
        ...


    def println(self, x: int) -> None:
        """
        Prints an integer and then terminates the line.  This method behaves as
        though it invokes .print(int) and then .println().

        Arguments
        - x: the `int` value to be printed
        """
        ...


    def println(self, x: int) -> None:
        """
        Prints a long integer and then terminates the line.  This method behaves
        as though it invokes .print(long) and then
        .println().

        Arguments
        - x: the `long` value to be printed
        """
        ...


    def println(self, x: float) -> None:
        """
        Prints a floating-point number and then terminates the line.  This method
        behaves as though it invokes .print(float) and then
        .println().

        Arguments
        - x: the `float` value to be printed
        """
        ...


    def println(self, x: float) -> None:
        """
        Prints a double-precision floating-point number and then terminates the
        line.  This method behaves as though it invokes .print(double) and then .println().

        Arguments
        - x: the `double` value to be printed
        """
        ...


    def println(self, x: list[str]) -> None:
        """
        Prints an array of characters and then terminates the line.  This method
        behaves as though it invokes .print(char[]) and then
        .println().

        Arguments
        - x: the array of `char` values to be printed
        """
        ...


    def println(self, x: str) -> None:
        """
        Prints a String and then terminates the line.  This method behaves as
        though it invokes .print(String) and then
        .println().

        Arguments
        - x: the `String` value to be printed
        """
        ...


    def println(self, x: "Object") -> None:
        """
        Prints an Object and then terminates the line.  This method calls
        at first String.valueOf(x) to get the printed object's string value,
        then behaves as
        though it invokes .print(String) and then
        .println().

        Arguments
        - x: The `Object` to be printed.
        """
        ...


    def printf(self, format: str, *args: Tuple["Object", ...]) -> "PrintWriter":
        """
        A convenience method to write a formatted string to this writer using
        the specified format string and arguments.  If automatic flushing is
        enabled, calls to this method will flush the output buffer.
        
         An invocation of this method of the form
        `out.printf(format, args)`
        behaves in exactly the same way as the invocation
        
        ````out.format(format, args)````

        Arguments
        - format: A format string as described in <a
                href="../util/Formatter.html#syntax">Format string syntax</a>.
        - args: Arguments referenced by the format specifiers in the format
                string.  If there are more arguments than format specifiers, the
                extra arguments are ignored.  The number of arguments is
                variable and may be zero.  The maximum number of arguments is
                limited by the maximum dimension of a Java array as defined by
                <cite>The Java Virtual Machine Specification</cite>.
                The behaviour on a
                `null` argument depends on the <a
                href="../util/Formatter.html#syntax">conversion</a>.

        Returns
        - This writer

        Raises
        - java.util.IllegalFormatException: If a format string contains an illegal syntax, a format
                 specifier that is incompatible with the given arguments,
                 insufficient arguments given the format string, or other
                 illegal conditions.  For specification of all possible
                 formatting errors, see the <a
                 href="../util/Formatter.html#detail">Details</a> section of the
                 formatter class specification.
        - NullPointerException: If the `format` is `null`

        Since
        - 1.5
        """
        ...


    def printf(self, l: "Locale", format: str, *args: Tuple["Object", ...]) -> "PrintWriter":
        """
        A convenience method to write a formatted string to this writer using
        the specified format string and arguments.  If automatic flushing is
        enabled, calls to this method will flush the output buffer.
        
         An invocation of this method of the form
        `out.printf(l, format, args)`
        behaves in exactly the same way as the invocation
        
        ````out.format(l, format, args)````

        Arguments
        - l: The java.util.Locale locale to apply during
                formatting.  If `l` is `null` then no localization
                is applied.
        - format: A format string as described in <a
                href="../util/Formatter.html#syntax">Format string syntax</a>.
        - args: Arguments referenced by the format specifiers in the format
                string.  If there are more arguments than format specifiers, the
                extra arguments are ignored.  The number of arguments is
                variable and may be zero.  The maximum number of arguments is
                limited by the maximum dimension of a Java array as defined by
                <cite>The Java Virtual Machine Specification</cite>.
                The behaviour on a
                `null` argument depends on the <a
                href="../util/Formatter.html#syntax">conversion</a>.

        Returns
        - This writer

        Raises
        - java.util.IllegalFormatException: If a format string contains an illegal syntax, a format
                 specifier that is incompatible with the given arguments,
                 insufficient arguments given the format string, or other
                 illegal conditions.  For specification of all possible
                 formatting errors, see the <a
                 href="../util/Formatter.html#detail">Details</a> section of the
                 formatter class specification.
        - NullPointerException: If the `format` is `null`

        Since
        - 1.5
        """
        ...


    def format(self, format: str, *args: Tuple["Object", ...]) -> "PrintWriter":
        """
        Writes a formatted string to this writer using the specified format
        string and arguments.  If automatic flushing is enabled, calls to this
        method will flush the output buffer.
        
         The locale always used is the one returned by java.util.Locale.getDefault() Locale.getDefault(), regardless of any
        previous invocations of other formatting methods on this object.

        Arguments
        - format: A format string as described in <a
                href="../util/Formatter.html#syntax">Format string syntax</a>.
        - args: Arguments referenced by the format specifiers in the format
                string.  If there are more arguments than format specifiers, the
                extra arguments are ignored.  The number of arguments is
                variable and may be zero.  The maximum number of arguments is
                limited by the maximum dimension of a Java array as defined by
                <cite>The Java Virtual Machine Specification</cite>.
                The behaviour on a
                `null` argument depends on the <a
                href="../util/Formatter.html#syntax">conversion</a>.

        Returns
        - This writer

        Raises
        - java.util.IllegalFormatException: If a format string contains an illegal syntax, a format
                 specifier that is incompatible with the given arguments,
                 insufficient arguments given the format string, or other
                 illegal conditions.  For specification of all possible
                 formatting errors, see the <a
                 href="../util/Formatter.html#detail">Details</a> section of the
                 Formatter class specification.
        - NullPointerException: If the `format` is `null`

        Since
        - 1.5
        """
        ...


    def format(self, l: "Locale", format: str, *args: Tuple["Object", ...]) -> "PrintWriter":
        """
        Writes a formatted string to this writer using the specified format
        string and arguments.  If automatic flushing is enabled, calls to this
        method will flush the output buffer.

        Arguments
        - l: The java.util.Locale locale to apply during
                formatting.  If `l` is `null` then no localization
                is applied.
        - format: A format string as described in <a
                href="../util/Formatter.html#syntax">Format string syntax</a>.
        - args: Arguments referenced by the format specifiers in the format
                string.  If there are more arguments than format specifiers, the
                extra arguments are ignored.  The number of arguments is
                variable and may be zero.  The maximum number of arguments is
                limited by the maximum dimension of a Java array as defined by
                <cite>The Java Virtual Machine Specification</cite>.
                The behaviour on a
                `null` argument depends on the <a
                href="../util/Formatter.html#syntax">conversion</a>.

        Returns
        - This writer

        Raises
        - java.util.IllegalFormatException: If a format string contains an illegal syntax, a format
                 specifier that is incompatible with the given arguments,
                 insufficient arguments given the format string, or other
                 illegal conditions.  For specification of all possible
                 formatting errors, see the <a
                 href="../util/Formatter.html#detail">Details</a> section of the
                 formatter class specification.
        - NullPointerException: If the `format` is `null`

        Since
        - 1.5
        """
        ...


    def append(self, csq: "CharSequence") -> "PrintWriter":
        """
        Appends the specified character sequence to this writer.
        
         An invocation of this method of the form `out.append(csq)`
        behaves in exactly the same way as the invocation
        
        ````out.write(csq.toString())````
        
         Depending on the specification of `toString` for the
        character sequence `csq`, the entire sequence may not be
        appended. For instance, invoking the `toString` method of a
        character buffer will return a subsequence whose content depends upon
        the buffer's position and limit.

        Arguments
        - csq: The character sequence to append.  If `csq` is
                `null`, then the four characters `"null"` are
                appended to this writer.

        Returns
        - This writer

        Since
        - 1.5
        """
        ...


    def append(self, csq: "CharSequence", start: int, end: int) -> "PrintWriter":
        """
        Appends a subsequence of the specified character sequence to this writer.
        
         An invocation of this method of the form
        `out.append(csq, start, end)`
        when `csq` is not `null`, behaves in
        exactly the same way as the invocation
        
        ````out.write(csq.subSequence(start, end).toString())````

        Arguments
        - csq: The character sequence from which a subsequence will be
                appended.  If `csq` is `null`, then characters
                will be appended as if `csq` contained the four
                characters `"null"`.
        - start: The index of the first character in the subsequence
        - end: The index of the character following the last character in the
                subsequence

        Returns
        - This writer

        Raises
        - IndexOutOfBoundsException: If `start` or `end` are negative, `start`
                 is greater than `end`, or `end` is greater than
                 `csq.length()`

        Since
        - 1.5
        """
        ...


    def append(self, c: str) -> "PrintWriter":
        """
        Appends the specified character to this writer.
        
         An invocation of this method of the form `out.append(c)`
        behaves in exactly the same way as the invocation
        
        ````out.write(c)````

        Arguments
        - c: The 16-bit character to append

        Returns
        - This writer

        Since
        - 1.5
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.inventory.BrewEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.block import BlockEvent
from org.bukkit.event.inventory import *
from org.bukkit.inventory import BrewerInventory
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class BrewEvent(BlockEvent, Cancellable):
    """
    Called when the brewing of the contents inside the Brewing Stand is
    complete.
    """

    def __init__(self, brewer: "Block", contents: "BrewerInventory", results: list["ItemStack"], fuelLevel: int):
        ...


    def getContents(self) -> "BrewerInventory":
        """
        Gets the contents of the Brewing Stand.
        
        **Note:** The brewer inventory still holds the items found prior to
        the finalization of the brewing process, e.g. the plain water bottles.

        Returns
        - the contents
        """
        ...


    def getFuelLevel(self) -> int:
        """
        Gets the remaining fuel level.

        Returns
        - the remaining fuel
        """
        ...


    def getResults(self) -> list["ItemStack"]:
        """
        Gets the resulting items in the Brewing Stand.
        
        The returned list, in case of a server-created event instance, is
        mutable. Any changes in the returned list will reflect in the brewing
        result if the event is not cancelled. If the size of the list is reduced,
        remaining items will be set to air.

        Returns
        - List of ItemStack resulting for this operation
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.block.Block

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Chunk
from org.bukkit import FluidCollisionMode
from org.bukkit import Location
from org.bukkit import Material
from org.bukkit import Translatable
from org.bukkit import World
from org.bukkit.block import *
from org.bukkit.block.data import Bisected
from org.bukkit.block.data import BlockData
from org.bukkit.entity import Entity
from org.bukkit.entity import Player
from org.bukkit.inventory import ItemStack
from org.bukkit.metadata import Metadatable
from org.bukkit.util import BoundingBox
from org.bukkit.util import RayTraceResult
from org.bukkit.util import Vector
from org.bukkit.util import VoxelShape
from typing import Any, Callable, Iterable, Tuple


class Block(Metadatable, Translatable):
    """
    Represents a block. This is a live object, and only one Block may exist for
    any given location in a world. The state of the block may change
    concurrently to your own handling of it; use block.getState() to get a
    snapshot state of a block which will not be modified.
    
    
    Note that parts of this class which require access to the world at large
    (i.e. lighting and power) may not be able to be safely accessed during world
    generation when used in cases like BlockPhysicsEvent!!!!
    """

    def getData(self) -> int:
        """
        Gets the metadata for this block

        Returns
        - block specific metadata

        Deprecated
        - Magic value
        """
        ...


    def getBlockData(self) -> "BlockData":
        """
        Gets the complete block data for this block

        Returns
        - block specific data
        """
        ...


    def getRelative(self, modX: int, modY: int, modZ: int) -> "Block":
        """
        Gets the block at the given offsets

        Arguments
        - modX: X-coordinate offset
        - modY: Y-coordinate offset
        - modZ: Z-coordinate offset

        Returns
        - Block at the given offsets
        """
        ...


    def getRelative(self, face: "BlockFace") -> "Block":
        """
        Gets the block at the given face
        
        This method is equal to getRelative(face, 1)

        Arguments
        - face: Face of this block to return

        Returns
        - Block at the given face

        See
        - .getRelative(BlockFace, int)
        """
        ...


    def getRelative(self, face: "BlockFace", distance: int) -> "Block":
        """
        Gets the block at the given distance of the given face
        
        For example, the following method places water at 100,102,100; two
        blocks above 100,100,100.
        
        ```
        Block block = world.getBlockAt(100, 100, 100);
        Block shower = block.getRelative(BlockFace.UP, 2);
        shower.setType(Material.WATER);
        ```

        Arguments
        - face: Face of this block to return
        - distance: Distance to get the block at

        Returns
        - Block at the given face
        """
        ...


    def getType(self) -> "Material":
        """
        Gets the type of this block

        Returns
        - block type
        """
        ...


    def getLightLevel(self) -> int:
        """
        Gets the light level between 0-15

        Returns
        - light level
        """
        ...


    def getLightFromSky(self) -> int:
        """
        Get the amount of light at this block from the sky.
        
        Any light given from other sources (such as blocks like torches) will
        be ignored.

        Returns
        - Sky light level
        """
        ...


    def getLightFromBlocks(self) -> int:
        """
        Get the amount of light at this block from nearby blocks.
        
        Any light given from other sources (such as the sun) will be ignored.

        Returns
        - Block light level
        """
        ...


    def getWorld(self) -> "World":
        """
        Gets the world which contains this Block

        Returns
        - World containing this block
        """
        ...


    def getX(self) -> int:
        """
        Gets the x-coordinate of this block

        Returns
        - x-coordinate
        """
        ...


    def getY(self) -> int:
        """
        Gets the y-coordinate of this block

        Returns
        - y-coordinate
        """
        ...


    def getZ(self) -> int:
        """
        Gets the z-coordinate of this block

        Returns
        - z-coordinate
        """
        ...


    def getLocation(self) -> "Location":
        """
        Gets the Location of the block

        Returns
        - Location of block
        """
        ...


    def getLocation(self, loc: "Location") -> "Location":
        """
        Stores the location of the block in the provided Location object.
        
        If the provided Location is null this method does nothing and returns
        null.

        Arguments
        - loc: the location to copy into

        Returns
        - The Location object provided or null
        """
        ...


    def getChunk(self) -> "Chunk":
        """
        Gets the chunk which contains this block

        Returns
        - Containing Chunk
        """
        ...


    def setBlockData(self, data: "BlockData") -> None:
        """
        Sets the complete data for this block

        Arguments
        - data: new block specific data
        """
        ...


    def setBlockData(self, data: "BlockData", applyPhysics: bool) -> None:
        """
        Sets the complete data for this block
        
        
        Note that applyPhysics = False is not in general safe. It should only be
        used when you need to avoid triggering a physics update of neighboring
        blocks, for example when creating a Bisected block. If you are
        using a custom populator, then this parameter may also be required to
        prevent triggering infinite chunk loads on border blocks. This method
        should NOT be used to "hack" physics by placing blocks in impossible
        locations. Such blocks are liable to be removed on various events such as
        world upgrades. Furthermore setting large amounts of such blocks in close
        proximity may overload the server physics engine if an update is
        triggered at a later point. If this occurs, the resulting behavior is
        undefined.

        Arguments
        - data: new block specific data
        - applyPhysics: False to cancel physics from the changed block
        """
        ...


    def setType(self, type: "Material") -> None:
        """
        Sets the type of this block

        Arguments
        - type: Material to change this block to
        """
        ...


    def setType(self, type: "Material", applyPhysics: bool) -> None:
        """
        Sets the type of this block
        
        
        Note that applyPhysics = False is not in general safe. It should only be
        used when you need to avoid triggering a physics update of neighboring
        blocks, for example when creating a Bisected block. If you are
        using a custom populator, then this parameter may also be required to
        prevent triggering infinite chunk loads on border blocks. This method
        should NOT be used to "hack" physics by placing blocks in impossible
        locations. Such blocks are liable to be removed on various events such as
        world upgrades. Furthermore setting large amounts of such blocks in close
        proximity may overload the server physics engine if an update is
        triggered at a later point. If this occurs, the resulting behavior is
        undefined.

        Arguments
        - type: Material to change this block to
        - applyPhysics: False to cancel physics on the changed block.
        """
        ...


    def getFace(self, block: "Block") -> "BlockFace":
        """
        Gets the face relation of this block compared to the given block.
        
        For example:
        ````Block current = world.getBlockAt(100, 100, 100);
        Block target = world.getBlockAt(100, 101, 100);
        
        current.getFace(target) == BlockFace.Up;````
        
        If the given block is not connected to this block, null may be returned

        Arguments
        - block: Block to compare against this block

        Returns
        - BlockFace of this block which has the requested block, or null
        """
        ...


    def getState(self) -> "BlockState":
        """
        Captures the current state of this block. You may then cast that state
        into any accepted type, such as Furnace or Sign.
        
        The returned object will never be updated, and you are not guaranteed
        that (for example) a sign is still a sign after you capture its state.

        Returns
        - BlockState with the current state of this block.
        """
        ...


    def getBiome(self) -> "Biome":
        """
        Returns the biome that this block resides in

        Returns
        - Biome type containing this block
        """
        ...


    def setBiome(self, bio: "Biome") -> None:
        """
        Sets the biome that this block resides in

        Arguments
        - bio: new Biome type for this block
        """
        ...


    def isBlockPowered(self) -> bool:
        """
        Returns True if the block is being powered by Redstone.

        Returns
        - True if the block is powered.
        """
        ...


    def isBlockIndirectlyPowered(self) -> bool:
        """
        Returns True if the block is being indirectly powered by Redstone.

        Returns
        - True if the block is indirectly powered.
        """
        ...


    def isBlockFacePowered(self, face: "BlockFace") -> bool:
        """
        Returns True if the block face is being powered by Redstone.

        Arguments
        - face: The block face

        Returns
        - True if the block face is powered.
        """
        ...


    def isBlockFaceIndirectlyPowered(self, face: "BlockFace") -> bool:
        """
        Returns True if the block face is being indirectly powered by Redstone.

        Arguments
        - face: The block face

        Returns
        - True if the block face is indirectly powered.
        """
        ...


    def getBlockPower(self, face: "BlockFace") -> int:
        """
        Returns the redstone power being provided to this block face

        Arguments
        - face: the face of the block to query or BlockFace.SELF for the
            block itself

        Returns
        - The power level.
        """
        ...


    def getBlockPower(self) -> int:
        """
        Returns the redstone power being provided to this block

        Returns
        - The power level.
        """
        ...


    def isEmpty(self) -> bool:
        """
        Checks if this block is empty.
        
        A block is considered empty when .getType() returns Material.AIR.

        Returns
        - True if this block is empty
        """
        ...


    def isLiquid(self) -> bool:
        """
        Checks if this block is liquid.
        
        A block is considered liquid when .getType() returns Material.WATER or Material.LAVA.

        Returns
        - True if this block is liquid
        """
        ...


    def getTemperature(self) -> float:
        """
        Gets the temperature of this block.
        
        If the raw biome temperature without adjusting for height effects is
        required then please use World.getTemperature(int, int).

        Returns
        - Temperature of this block
        """
        ...


    def getHumidity(self) -> float:
        """
        Gets the humidity of the biome of this block

        Returns
        - Humidity of this block
        """
        ...


    def getPistonMoveReaction(self) -> "PistonMoveReaction":
        """
        Returns the reaction of the block when moved by a piston

        Returns
        - reaction
        """
        ...


    def breakNaturally(self) -> bool:
        """
        Breaks the block and spawns items as if a player had digged it regardless
        of the tool.

        Returns
        - True if the block was destroyed
        """
        ...


    def breakNaturally(self, tool: "ItemStack") -> bool:
        """
        Breaks the block and spawns items as if a player had digged it with a
        specific tool

        Arguments
        - tool: The tool or item in hand used for digging

        Returns
        - True if the block was destroyed
        """
        ...


    def applyBoneMeal(self, face: "BlockFace") -> bool:
        """
        Simulate bone meal application to this block (if possible).

        Arguments
        - face: the face on which bonemeal should be applied

        Returns
        - True if the block was bonemealed, False otherwise
        """
        ...


    def getDrops(self) -> Iterable["ItemStack"]:
        """
        Returns a list of items which would drop by destroying this block

        Returns
        - a list of dropped items for this type of block
        """
        ...


    def getDrops(self, tool: "ItemStack") -> Iterable["ItemStack"]:
        """
        Returns a list of items which would drop by destroying this block with
        a specific tool

        Arguments
        - tool: The tool or item in hand used for digging

        Returns
        - a list of dropped items for this type of block
        """
        ...


    def getDrops(self, tool: "ItemStack", entity: "Entity") -> Iterable["ItemStack"]:
        """
        Returns a list of items which would drop by the entity destroying this
        block with a specific tool

        Arguments
        - tool: The tool or item in hand used for digging
        - entity: the entity destroying the block

        Returns
        - a list of dropped items for this type of block
        """
        ...


    def isPreferredTool(self, tool: "ItemStack") -> bool:
        """
        Returns if the given item is a preferred choice to break this Block.
        
        In some cases this determines if a block will drop anything or extra
        loot.

        Arguments
        - tool: The tool or item used for breaking this block

        Returns
        - True if the tool is preferred for breaking this block.
        """
        ...


    def getBreakSpeed(self, player: "Player") -> float:
        """
        Gets the speed at which the given player would break this block, taking
        into account tools, potion effects, whether or not the player is in
        water, enchantments, etc.
        
        The returned value is the amount of progress made in breaking the block
        each tick. When the total breaking progress reaches `1.0f`, the
        block is broken. Note that the break speed can change in the course of
        breaking a block, e.g. if a potion effect is applied or expires, or the
        player jumps/enters water.

        Arguments
        - player: player breaking the block

        Returns
        - the speed at which the player breaks this block
        """
        ...


    def isPassable(self) -> bool:
        """
        Checks if this block is passable.
        
        A block is passable if it has no colliding parts that would prevent
        players from moving through it.
        
        Examples: Tall grass, flowers, signs, etc. are passable, but open doors,
        fence gates, trap doors, etc. are not because they still have parts that
        can be collided with.

        Returns
        - `True` if passable
        """
        ...


    def rayTrace(self, start: "Location", direction: "Vector", maxDistance: float, fluidCollisionMode: "FluidCollisionMode") -> "RayTraceResult":
        """
        Performs a ray trace that checks for collision with this specific block
        in its current state using its precise collision shape.

        Arguments
        - start: the start location
        - direction: the ray direction
        - maxDistance: the maximum distance
        - fluidCollisionMode: the fluid collision mode

        Returns
        - the ray trace hit result, or `null` if there is no hit
        """
        ...


    def getBoundingBox(self) -> "BoundingBox":
        """
        Gets the approximate bounding box for this block.
        
        This isn't exact as some blocks org.bukkit.block.data.type.Stairs
        contain many bounding boxes to establish their complete form.
        
        Also, the box may not be exactly the same as the collision shape (such as
        cactus, which is 16/16 of a block with 15/16 collisional bounds).
        
        This method will return an empty bounding box if the geometric shape of
        the block is empty (such as air blocks).

        Returns
        - the approximate bounding box of the block
        """
        ...


    def getCollisionShape(self) -> "VoxelShape":
        """
        Gets the collision shape of this block.

        Returns
        - a VoxelShape representing the collision shape of this
        block.
        """
        ...


    def canPlace(self, data: "BlockData") -> bool:
        """
        Checks if this block is a valid placement location for the specified
        block data.

        Arguments
        - data: the block data to check

        Returns
        - `True` if the block data can be placed here
        """
        ...



"""
Python module generated from Java source file java.net.URLClassLoader

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import Closeable
from java.io import File
from java.io import FilePermission
from java.io import IOException
from java.io import InputStream
from java.net import *
from java.security import AccessControlContext
from java.security import AccessController
from java.security import CodeSigner
from java.security import CodeSource
from java.security import Permission
from java.security import PermissionCollection
from java.security import PrivilegedAction
from java.security import PrivilegedExceptionAction
from java.security import SecureClassLoader
from java.util import Enumeration
from java.util import NoSuchElementException
from java.util import Objects
from java.util import WeakHashMap
from java.util.jar import Attributes
from java.util.jar.Attributes import Name
from java.util.jar import JarFile
from java.util.jar import Manifest
from jdk.internal.access import SharedSecrets
from jdk.internal.loader import Resource
from jdk.internal.loader import URLClassPath
from jdk.internal.perf import PerfCounter
from sun.net.www import ParseUtil
from sun.security.util import SecurityConstants
from typing import Any, Callable, Iterable, Tuple


class URLClassLoader(SecureClassLoader, Closeable):
    """
    This class loader is used to load classes and resources from a search
    path of URLs referring to both JAR files and directories. Any `jar:`
    scheme URL (see java.net.JarURLConnection) is assumed to refer to a
    JAR file.  Any `file:` scheme URL that ends with a '/' is assumed to
    refer to a directory. Otherwise, the URL is assumed to refer to a JAR file
    which will be opened as needed.
    
    This class loader supports the loading of classes and resources from the
    contents of a <a href="../util/jar/JarFile.html#multirelease">multi-release</a>
    JAR file that is referred to by a given URL.
    
    The AccessControlContext of the thread that created the instance of
    URLClassLoader will be used when subsequently loading classes and
    resources.
    
    The classes that are loaded are by default granted permission only to
    access the URLs specified when the URLClassLoader was created.

    Author(s)
    - David Connelly

    Since
    - 1.2
    """

    def __init__(self, urls: list["URL"], parent: "ClassLoader"):
        """
        Constructs a new URLClassLoader for the given URLs. The URLs will be
        searched in the order specified for classes and resources after first
        searching in the specified parent class loader.  Any `jar:`
        scheme URL is assumed to refer to a JAR file.  Any `file:` scheme
        URL that ends with a '/' is assumed to refer to a directory.  Otherwise,
        the URL is assumed to refer to a JAR file which will be downloaded and
        opened as needed.
        
        If there is a security manager, this method first
        calls the security manager's `checkCreateClassLoader` method
        to ensure creation of a class loader is allowed.

        Arguments
        - urls: the URLs from which to load classes and resources
        - parent: the parent class loader for delegation

        Raises
        - SecurityException: if a security manager exists and its
                    `checkCreateClassLoader` method doesn't allow
                    creation of a class loader.
        - NullPointerException: if `urls` or any of its
                    elements is `null`.

        See
        - SecurityManager.checkCreateClassLoader
        """
        ...


    def __init__(self, urls: list["URL"]):
        """
        Constructs a new URLClassLoader for the specified URLs using the
        default delegation parent `ClassLoader`. The URLs will
        be searched in the order specified for classes and resources after
        first searching in the parent class loader. Any URL that ends with
        a '/' is assumed to refer to a directory. Otherwise, the URL is
        assumed to refer to a JAR file which will be downloaded and opened
        as needed.
        
        If there is a security manager, this method first
        calls the security manager's `checkCreateClassLoader` method
        to ensure creation of a class loader is allowed.

        Arguments
        - urls: the URLs from which to load classes and resources

        Raises
        - SecurityException: if a security manager exists and its
                    `checkCreateClassLoader` method doesn't allow
                    creation of a class loader.
        - NullPointerException: if `urls` or any of its
                    elements is `null`.

        See
        - SecurityManager.checkCreateClassLoader
        """
        ...


    def __init__(self, urls: list["URL"], parent: "ClassLoader", factory: "URLStreamHandlerFactory"):
        """
        Constructs a new URLClassLoader for the specified URLs, parent
        class loader, and URLStreamHandlerFactory. The parent argument
        will be used as the parent class loader for delegation. The
        factory argument will be used as the stream handler factory to
        obtain protocol handlers when creating new jar URLs.
        
        If there is a security manager, this method first
        calls the security manager's `checkCreateClassLoader` method
        to ensure creation of a class loader is allowed.

        Arguments
        - urls: the URLs from which to load classes and resources
        - parent: the parent class loader for delegation
        - factory: the URLStreamHandlerFactory to use when creating URLs

        Raises
        - SecurityException: if a security manager exists and its
                `checkCreateClassLoader` method doesn't allow
                creation of a class loader.
        - NullPointerException: if `urls` or any of its
                elements is `null`.

        See
        - SecurityManager.checkCreateClassLoader
        """
        ...


    def __init__(self, name: str, urls: list["URL"], parent: "ClassLoader"):
        """
        Constructs a new named `URLClassLoader` for the specified URLs.
        The URLs will be searched in the order specified for classes
        and resources after first searching in the specified parent class loader.
        Any URL that ends with a '/' is assumed to refer to a directory.
        Otherwise, the URL is assumed to refer to a JAR file which will be
        downloaded and opened as needed.

        Arguments
        - name: class loader name; or `null` if not named
        - urls: the URLs from which to load classes and resources
        - parent: the parent class loader for delegation

        Raises
        - IllegalArgumentException: if the given name is empty.
        - NullPointerException: if `urls` or any of its
                elements is `null`.
        - SecurityException: if a security manager exists and its
                SecurityManager.checkCreateClassLoader() method doesn't
                allow creation of a class loader.

        Since
        - 9
        """
        ...


    def __init__(self, name: str, urls: list["URL"], parent: "ClassLoader", factory: "URLStreamHandlerFactory"):
        """
        Constructs a new named `URLClassLoader` for the specified URLs,
        parent class loader, and URLStreamHandlerFactory.
        The parent argument will be used as the parent class loader for delegation.
        The factory argument will be used as the stream handler factory to
        obtain protocol handlers when creating new jar URLs.

        Arguments
        - name: class loader name; or `null` if not named
        - urls: the URLs from which to load classes and resources
        - parent: the parent class loader for delegation
        - factory: the URLStreamHandlerFactory to use when creating URLs

        Raises
        - IllegalArgumentException: if the given name is empty.
        - NullPointerException: if `urls` or any of its
                elements is `null`.
        - SecurityException: if a security manager exists and its
                `checkCreateClassLoader` method doesn't allow
                creation of a class loader.

        Since
        - 9
        """
        ...


    def getResourceAsStream(self, name: str) -> "InputStream":
        """
        Returns an input stream for reading the specified resource.
        If this loader is closed, then any resources opened by this method
        will be closed.
        
         The search order is described in the documentation for .getResource(String).  

        Arguments
        - name: The resource name

        Returns
        - An input stream for reading the resource, or `null`
                 if the resource could not be found

        Raises
        - NullPointerException: If `name` is `null`

        Since
        - 1.7
        """
        ...


    def close(self) -> None:
        """
        Closes this URLClassLoader, so that it can no longer be used to load
        new classes or resources that are defined by this loader.
        Classes and resources defined by any of this loader's parents in the
        delegation hierarchy are still accessible. Also, any classes or resources
        that are already loaded, are still accessible.
        
        In the case of jar: and file: URLs, it also closes any files
        that were opened by it. If another thread is loading a
        class when the `close` method is invoked, then the result of
        that load is undefined.
        
        The method makes a best effort attempt to close all opened files,
        by catching IOExceptions internally. Unchecked exceptions
        and errors are not caught. Calling close on an already closed
        loader has no effect.

        Raises
        - IOException: if closing any file opened by this class loader
        resulted in an IOException. Any such exceptions are caught internally.
        If only one is caught, then it is re-thrown. If more than one exception
        is caught, then the second and following exceptions are added
        as suppressed exceptions of the first one caught, which is then re-thrown.
        - SecurityException: if a security manager is set, and it denies
          RuntimePermission`("closeClassLoader")`

        Since
        - 1.7
        """
        ...


    def getURLs(self) -> list["URL"]:
        """
        Returns the search path of URLs for loading classes and resources.
        This includes the original list of URLs specified to the constructor,
        along with any URLs subsequently appended by the addURL() method.

        Returns
        - the search path of URLs for loading classes and resources.
        """
        ...


    def findResource(self, name: str) -> "URL":
        """
        Finds the resource with the specified name on the URL search path.

        Arguments
        - name: the name of the resource

        Returns
        - a `URL` for the resource, or `null`
        if the resource could not be found, or if the loader is closed.
        """
        ...


    def findResources(self, name: str) -> "Enumeration"["URL"]:
        """
        Returns an Enumeration of URLs representing all of the resources
        on the URL search path having the specified name.

        Arguments
        - name: the resource name

        Returns
        - An `Enumeration` of `URL`s.
                If the loader is closed, the Enumeration contains no elements.

        Raises
        - IOException: if an I/O exception occurs
        """
        ...


    @staticmethod
    def newInstance(urls: list["URL"], parent: "ClassLoader") -> "URLClassLoader":
        """
        Creates a new instance of URLClassLoader for the specified
        URLs and parent class loader. If a security manager is
        installed, the `loadClass` method of the URLClassLoader
        returned by this method will invoke the
        `SecurityManager.checkPackageAccess` method before
        loading the class.

        Arguments
        - urls: the URLs to search for classes and resources
        - parent: the parent class loader for delegation

        Returns
        - the resulting class loader

        Raises
        - NullPointerException: if `urls` or any of its
                    elements is `null`.
        """
        ...


    @staticmethod
    def newInstance(urls: list["URL"]) -> "URLClassLoader":
        """
        Creates a new instance of URLClassLoader for the specified
        URLs and default parent class loader. If a security manager is
        installed, the `loadClass` method of the URLClassLoader
        returned by this method will invoke the
        `SecurityManager.checkPackageAccess` before
        loading the class.

        Arguments
        - urls: the URLs to search for classes and resources

        Returns
        - the resulting class loader

        Raises
        - NullPointerException: if `urls` or any of its
                    elements is `null`.
        """
        ...
